from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.Networking.WinHttp
import win32more.Windows.Win32.Networking.WinInet
import win32more.Windows.Win32.Security.Authentication.Identity
import win32more.Windows.Win32.Security.Cryptography
import win32more.Windows.Win32.Storage.FileSystem
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class APP_CACHE_DOWNLOAD_ENTRY(Structure):
    pwszUrl: win32more.Windows.Win32.Foundation.PWSTR
    dwEntryType: UInt32
class APP_CACHE_DOWNLOAD_LIST(Structure):
    dwEntryCount: UInt32
    pEntries: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_DOWNLOAD_ENTRY)
APP_CACHE_FINALIZE_STATE = Int32
AppCacheFinalizeStateIncomplete: win32more.Windows.Win32.Networking.WinInet.APP_CACHE_FINALIZE_STATE = 0
AppCacheFinalizeStateManifestChange: win32more.Windows.Win32.Networking.WinInet.APP_CACHE_FINALIZE_STATE = 1
AppCacheFinalizeStateComplete: win32more.Windows.Win32.Networking.WinInet.APP_CACHE_FINALIZE_STATE = 2
class APP_CACHE_GROUP_INFO(Structure):
    pwszManifestUrl: win32more.Windows.Win32.Foundation.PWSTR
    ftLastAccessTime: win32more.Windows.Win32.Foundation.FILETIME
    ullSize: UInt64
class APP_CACHE_GROUP_LIST(Structure):
    dwAppCacheGroupCount: UInt32
    pAppCacheGroups: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_GROUP_INFO)
APP_CACHE_STATE = Int32
AppCacheStateNoUpdateNeeded: win32more.Windows.Win32.Networking.WinInet.APP_CACHE_STATE = 0
AppCacheStateUpdateNeeded: win32more.Windows.Win32.Networking.WinInet.APP_CACHE_STATE = 1
AppCacheStateUpdateNeededNew: win32more.Windows.Win32.Networking.WinInet.APP_CACHE_STATE = 2
AppCacheStateUpdateNeededMasterOnly: win32more.Windows.Win32.Networking.WinInet.APP_CACHE_STATE = 3
class AUTO_PROXY_SCRIPT_BUFFER(Structure):
    dwStructSize: UInt32
    lpszScriptBuffer: win32more.Windows.Win32.Foundation.PSTR
    dwScriptBufferSize: UInt32
DIALPROP_USERNAME: String = 'UserName'
DIALPROP_PASSWORD: String = 'Password'
DIALPROP_DOMAIN: String = 'Domain'
DIALPROP_SAVEPASSWORD: String = 'SavePassword'
DIALPROP_REDIALCOUNT: String = 'RedialCount'
DIALPROP_REDIALINTERVAL: String = 'RedialInterval'
DIALPROP_PHONENUMBER: String = 'PhoneNumber'
DIALPROP_LASTERROR: String = 'LastError'
DIALPROP_RESOLVEDPHONE: String = 'ResolvedPhone'
DIALENG_OperationComplete: UInt32 = 65536
DIALENG_RedialAttempt: UInt32 = 65537
DIALENG_RedialWait: UInt32 = 65538
INTERNET_INVALID_PORT_NUMBER: UInt32 = 0
INTERNET_DEFAULT_FTP_PORT: UInt16 = 21
INTERNET_DEFAULT_GOPHER_PORT: UInt16 = 70
INTERNET_DEFAULT_SOCKS_PORT: UInt16 = 1080
INTERNET_MAX_HOST_NAME_LENGTH: UInt32 = 256
INTERNET_MAX_USER_NAME_LENGTH: UInt32 = 128
INTERNET_MAX_PASSWORD_LENGTH: UInt32 = 128
INTERNET_MAX_PORT_NUMBER_LENGTH: UInt32 = 5
INTERNET_MAX_PORT_NUMBER_VALUE: UInt32 = 65535
INTERNET_KEEP_ALIVE_UNKNOWN: UInt32 = 4294967295
INTERNET_KEEP_ALIVE_ENABLED: UInt32 = 1
INTERNET_KEEP_ALIVE_DISABLED: UInt32 = 0
INTERNET_REQFLAG_FROM_CACHE: UInt32 = 1
INTERNET_REQFLAG_ASYNC: UInt32 = 2
INTERNET_REQFLAG_VIA_PROXY: UInt32 = 4
INTERNET_REQFLAG_NO_HEADERS: UInt32 = 8
INTERNET_REQFLAG_PASSIVE: UInt32 = 16
INTERNET_REQFLAG_CACHE_WRITE_DISABLED: UInt32 = 64
INTERNET_REQFLAG_NET_TIMEOUT: UInt32 = 128
INTERNET_FLAG_IDN_DIRECT: UInt32 = 1
INTERNET_FLAG_IDN_PROXY: UInt32 = 2
INTERNET_FLAG_RELOAD: UInt32 = 2147483648
INTERNET_FLAG_RAW_DATA: UInt32 = 1073741824
INTERNET_FLAG_EXISTING_CONNECT: UInt32 = 536870912
INTERNET_FLAG_ASYNC: UInt32 = 268435456
INTERNET_FLAG_PASSIVE: UInt32 = 134217728
INTERNET_FLAG_NO_CACHE_WRITE: UInt32 = 67108864
INTERNET_FLAG_DONT_CACHE: UInt32 = 67108864
INTERNET_FLAG_MAKE_PERSISTENT: UInt32 = 33554432
INTERNET_FLAG_FROM_CACHE: UInt32 = 16777216
INTERNET_FLAG_OFFLINE: UInt32 = 16777216
INTERNET_FLAG_SECURE: UInt32 = 8388608
INTERNET_FLAG_KEEP_CONNECTION: UInt32 = 4194304
INTERNET_FLAG_NO_AUTO_REDIRECT: UInt32 = 2097152
INTERNET_FLAG_READ_PREFETCH: UInt32 = 1048576
INTERNET_FLAG_NO_COOKIES: UInt32 = 524288
INTERNET_FLAG_NO_AUTH: UInt32 = 262144
INTERNET_FLAG_CACHE_IF_NET_FAIL: UInt32 = 65536
INTERNET_FLAG_IGNORE_REDIRECT_TO_HTTP: UInt32 = 32768
INTERNET_FLAG_IGNORE_REDIRECT_TO_HTTPS: UInt32 = 16384
INTERNET_FLAG_IGNORE_CERT_DATE_INVALID: UInt32 = 8192
INTERNET_FLAG_IGNORE_CERT_CN_INVALID: UInt32 = 4096
INTERNET_FLAG_RESYNCHRONIZE: UInt32 = 2048
INTERNET_FLAG_HYPERLINK: UInt32 = 1024
INTERNET_FLAG_NO_UI: UInt32 = 512
INTERNET_FLAG_PRAGMA_NOCACHE: UInt32 = 256
INTERNET_FLAG_CACHE_ASYNC: UInt32 = 128
INTERNET_FLAG_FORMS_SUBMIT: UInt32 = 64
INTERNET_FLAG_FWD_BACK: UInt32 = 32
INTERNET_FLAG_NEED_FILE: UInt32 = 16
INTERNET_FLAG_MUST_CACHE_REQUEST: UInt32 = 16
INTERNET_ERROR_MASK_INSERT_CDROM: UInt32 = 1
INTERNET_ERROR_MASK_COMBINED_SEC_CERT: UInt32 = 2
INTERNET_ERROR_MASK_NEED_MSN_SSPI_PKG: UInt32 = 4
INTERNET_ERROR_MASK_LOGIN_FAILURE_DISPLAY_ENTITY_BODY: UInt32 = 8
WININET_API_FLAG_ASYNC: UInt32 = 1
WININET_API_FLAG_SYNC: UInt32 = 4
WININET_API_FLAG_USE_CONTEXT: UInt32 = 8
INTERNET_NO_CALLBACK: UInt32 = 0
IDSI_FLAG_KEEP_ALIVE: UInt32 = 1
IDSI_FLAG_SECURE: UInt32 = 2
IDSI_FLAG_PROXY: UInt32 = 4
IDSI_FLAG_TUNNEL: UInt32 = 8
INTERNET_PER_CONN_FLAGS_UI: UInt32 = 10
PROXY_TYPE_DIRECT: UInt32 = 1
PROXY_TYPE_PROXY: UInt32 = 2
PROXY_TYPE_AUTO_PROXY_URL: UInt32 = 4
PROXY_TYPE_AUTO_DETECT: UInt32 = 8
AUTO_PROXY_FLAG_USER_SET: UInt32 = 1
AUTO_PROXY_FLAG_ALWAYS_DETECT: UInt32 = 2
AUTO_PROXY_FLAG_DETECTION_RUN: UInt32 = 4
AUTO_PROXY_FLAG_MIGRATED: UInt32 = 8
AUTO_PROXY_FLAG_DONT_CACHE_PROXY_RESULT: UInt32 = 16
AUTO_PROXY_FLAG_CACHE_INIT_RUN: UInt32 = 32
AUTO_PROXY_FLAG_DETECTION_SUSPECT: UInt32 = 64
ISO_FORCE_DISCONNECTED: UInt32 = 1
INTERNET_RFC1123_FORMAT: UInt32 = 0
INTERNET_RFC1123_BUFSIZE: UInt32 = 30
ICU_USERNAME: UInt32 = 1073741824
INTERNET_OPEN_TYPE_PRECONFIG_WITH_NO_AUTOPROXY: UInt32 = 4
INTERNET_SERVICE_FTP: UInt32 = 1
INTERNET_SERVICE_GOPHER: UInt32 = 2
INTERNET_SERVICE_HTTP: UInt32 = 3
IRF_ASYNC: UInt32 = 1
IRF_SYNC: UInt32 = 4
IRF_USE_CONTEXT: UInt32 = 8
IRF_NO_WAIT: UInt32 = 8
ISO_GLOBAL: UInt32 = 1
ISO_REGISTRY: UInt32 = 2
INTERNET_OPTION_CALLBACK: UInt32 = 1
INTERNET_OPTION_CONNECT_TIMEOUT: UInt32 = 2
INTERNET_OPTION_CONNECT_RETRIES: UInt32 = 3
INTERNET_OPTION_CONNECT_BACKOFF: UInt32 = 4
INTERNET_OPTION_SEND_TIMEOUT: UInt32 = 5
INTERNET_OPTION_CONTROL_SEND_TIMEOUT: UInt32 = 5
INTERNET_OPTION_RECEIVE_TIMEOUT: UInt32 = 6
INTERNET_OPTION_CONTROL_RECEIVE_TIMEOUT: UInt32 = 6
INTERNET_OPTION_DATA_SEND_TIMEOUT: UInt32 = 7
INTERNET_OPTION_DATA_RECEIVE_TIMEOUT: UInt32 = 8
INTERNET_OPTION_HANDLE_TYPE: UInt32 = 9
INTERNET_OPTION_LISTEN_TIMEOUT: UInt32 = 11
INTERNET_OPTION_READ_BUFFER_SIZE: UInt32 = 12
INTERNET_OPTION_WRITE_BUFFER_SIZE: UInt32 = 13
INTERNET_OPTION_ASYNC_ID: UInt32 = 15
INTERNET_OPTION_ASYNC_PRIORITY: UInt32 = 16
INTERNET_OPTION_PARENT_HANDLE: UInt32 = 21
INTERNET_OPTION_KEEP_CONNECTION: UInt32 = 22
INTERNET_OPTION_REQUEST_FLAGS: UInt32 = 23
INTERNET_OPTION_EXTENDED_ERROR: UInt32 = 24
INTERNET_OPTION_OFFLINE_MODE: UInt32 = 26
INTERNET_OPTION_CACHE_STREAM_HANDLE: UInt32 = 27
INTERNET_OPTION_USERNAME: UInt32 = 28
INTERNET_OPTION_PASSWORD: UInt32 = 29
INTERNET_OPTION_ASYNC: UInt32 = 30
INTERNET_OPTION_SECURITY_FLAGS: UInt32 = 31
INTERNET_OPTION_SECURITY_CERTIFICATE_STRUCT: UInt32 = 32
INTERNET_OPTION_DATAFILE_NAME: UInt32 = 33
INTERNET_OPTION_URL: UInt32 = 34
INTERNET_OPTION_SECURITY_CERTIFICATE: UInt32 = 35
INTERNET_OPTION_SECURITY_KEY_BITNESS: UInt32 = 36
INTERNET_OPTION_REFRESH: UInt32 = 37
INTERNET_OPTION_PROXY: UInt32 = 38
INTERNET_OPTION_SETTINGS_CHANGED: UInt32 = 39
INTERNET_OPTION_VERSION: UInt32 = 40
INTERNET_OPTION_USER_AGENT: UInt32 = 41
INTERNET_OPTION_END_BROWSER_SESSION: UInt32 = 42
INTERNET_OPTION_PROXY_USERNAME: UInt32 = 43
INTERNET_OPTION_PROXY_PASSWORD: UInt32 = 44
INTERNET_OPTION_CONTEXT_VALUE: UInt32 = 45
INTERNET_OPTION_CONNECT_LIMIT: UInt32 = 46
INTERNET_OPTION_SECURITY_SELECT_CLIENT_CERT: UInt32 = 47
INTERNET_OPTION_POLICY: UInt32 = 48
INTERNET_OPTION_DISCONNECTED_TIMEOUT: UInt32 = 49
INTERNET_OPTION_CONNECTED_STATE: UInt32 = 50
INTERNET_OPTION_IDLE_STATE: UInt32 = 51
INTERNET_OPTION_OFFLINE_SEMANTICS: UInt32 = 52
INTERNET_OPTION_SECONDARY_CACHE_KEY: UInt32 = 53
INTERNET_OPTION_CALLBACK_FILTER: UInt32 = 54
INTERNET_OPTION_CONNECT_TIME: UInt32 = 55
INTERNET_OPTION_SEND_THROUGHPUT: UInt32 = 56
INTERNET_OPTION_RECEIVE_THROUGHPUT: UInt32 = 57
INTERNET_OPTION_REQUEST_PRIORITY: UInt32 = 58
INTERNET_OPTION_HTTP_VERSION: UInt32 = 59
INTERNET_OPTION_RESET_URLCACHE_SESSION: UInt32 = 60
INTERNET_OPTION_ERROR_MASK: UInt32 = 62
INTERNET_OPTION_FROM_CACHE_TIMEOUT: UInt32 = 63
INTERNET_OPTION_BYPASS_EDITED_ENTRY: UInt32 = 64
INTERNET_OPTION_HTTP_DECODING: UInt32 = 65
INTERNET_OPTION_DIAGNOSTIC_SOCKET_INFO: UInt32 = 67
INTERNET_OPTION_CODEPAGE: UInt32 = 68
INTERNET_OPTION_CACHE_TIMESTAMPS: UInt32 = 69
INTERNET_OPTION_DISABLE_AUTODIAL: UInt32 = 70
INTERNET_OPTION_MAX_CONNS_PER_SERVER: UInt32 = 73
INTERNET_OPTION_MAX_CONNS_PER_1_0_SERVER: UInt32 = 74
INTERNET_OPTION_PER_CONNECTION_OPTION: UInt32 = 75
INTERNET_OPTION_DIGEST_AUTH_UNLOAD: UInt32 = 76
INTERNET_OPTION_IGNORE_OFFLINE: UInt32 = 77
INTERNET_OPTION_IDENTITY: UInt32 = 78
INTERNET_OPTION_REMOVE_IDENTITY: UInt32 = 79
INTERNET_OPTION_ALTER_IDENTITY: UInt32 = 80
INTERNET_OPTION_SUPPRESS_BEHAVIOR: UInt32 = 81
INTERNET_OPTION_AUTODIAL_MODE: UInt32 = 82
INTERNET_OPTION_AUTODIAL_CONNECTION: UInt32 = 83
INTERNET_OPTION_CLIENT_CERT_CONTEXT: UInt32 = 84
INTERNET_OPTION_AUTH_FLAGS: UInt32 = 85
INTERNET_OPTION_COOKIES_3RD_PARTY: UInt32 = 86
INTERNET_OPTION_DISABLE_PASSPORT_AUTH: UInt32 = 87
INTERNET_OPTION_SEND_UTF8_SERVERNAME_TO_PROXY: UInt32 = 88
INTERNET_OPTION_EXEMPT_CONNECTION_LIMIT: UInt32 = 89
INTERNET_OPTION_ENABLE_PASSPORT_AUTH: UInt32 = 90
INTERNET_OPTION_HIBERNATE_INACTIVE_WORKER_THREADS: UInt32 = 91
INTERNET_OPTION_ACTIVATE_WORKER_THREADS: UInt32 = 92
INTERNET_OPTION_RESTORE_WORKER_THREAD_DEFAULTS: UInt32 = 93
INTERNET_OPTION_SOCKET_SEND_BUFFER_LENGTH: UInt32 = 94
INTERNET_OPTION_PROXY_SETTINGS_CHANGED: UInt32 = 95
INTERNET_OPTION_DATAFILE_EXT: UInt32 = 96
INTERNET_OPTION_CODEPAGE_PATH: UInt32 = 100
INTERNET_OPTION_CODEPAGE_EXTRA: UInt32 = 101
INTERNET_OPTION_IDN: UInt32 = 102
INTERNET_OPTION_MAX_CONNS_PER_PROXY: UInt32 = 103
INTERNET_OPTION_SUPPRESS_SERVER_AUTH: UInt32 = 104
INTERNET_OPTION_SERVER_CERT_CHAIN_CONTEXT: UInt32 = 105
INTERNET_OPTION_ENABLE_REDIRECT_CACHE_READ: UInt32 = 122
INTERNET_OPTION_COMPRESSED_CONTENT_LENGTH: UInt32 = 147
INTERNET_OPTION_ENABLE_HTTP_PROTOCOL: UInt32 = 148
INTERNET_OPTION_HTTP_PROTOCOL_USED: UInt32 = 149
INTERNET_OPTION_ENCODE_EXTRA: UInt32 = 155
INTERNET_OPTION_HSTS: UInt32 = 157
INTERNET_OPTION_ENTERPRISE_CONTEXT: UInt32 = 159
INTERNET_OPTION_CONNECTION_FILTER: UInt32 = 162
INTERNET_OPTION_REFERER_TOKEN_BINDING_HOSTNAME: UInt32 = 163
INTERNET_OPTION_TOKEN_BINDING_PUBLIC_KEY: UInt32 = 181
INTERNET_OPTION_COOKIES_SAME_SITE_LEVEL: UInt32 = 187
INTERNET_OPTION_REQUEST_ANNOTATION: UInt32 = 193
INTERNET_FIRST_OPTION: UInt32 = 1
INTERNET_LAST_OPTION: UInt32 = 193
INTERNET_PRIORITY_FOREGROUND: UInt32 = 1000
HTTP_COOKIES_SAME_SITE_LEVEL_UNKNOWN: UInt32 = 0
HTTP_COOKIES_SAME_SITE_LEVEL_SAME_SITE: UInt32 = 1
HTTP_COOKIES_SAME_SITE_LEVEL_CROSS_SITE_LAX: UInt32 = 2
HTTP_COOKIES_SAME_SITE_LEVEL_CROSS_SITE: UInt32 = 3
HTTP_COOKIES_SAME_SITE_LEVEL_MAX: UInt32 = 3
HTTP_PROTOCOL_FLAG_HTTP2: UInt32 = 2
HTTP_PROTOCOL_MASK: UInt32 = 2
INTERNET_OPTION_REQUEST_ANNOTATION_MAX_LENGTH: UInt32 = 64000
INTERNET_HANDLE_TYPE_INTERNET: UInt32 = 1
INTERNET_HANDLE_TYPE_CONNECT_FTP: UInt32 = 2
INTERNET_HANDLE_TYPE_CONNECT_GOPHER: UInt32 = 3
INTERNET_HANDLE_TYPE_CONNECT_HTTP: UInt32 = 4
INTERNET_HANDLE_TYPE_FTP_FIND: UInt32 = 5
INTERNET_HANDLE_TYPE_FTP_FIND_HTML: UInt32 = 6
INTERNET_HANDLE_TYPE_FTP_FILE: UInt32 = 7
INTERNET_HANDLE_TYPE_FTP_FILE_HTML: UInt32 = 8
INTERNET_HANDLE_TYPE_GOPHER_FIND: UInt32 = 9
INTERNET_HANDLE_TYPE_GOPHER_FIND_HTML: UInt32 = 10
INTERNET_HANDLE_TYPE_GOPHER_FILE: UInt32 = 11
INTERNET_HANDLE_TYPE_GOPHER_FILE_HTML: UInt32 = 12
INTERNET_HANDLE_TYPE_HTTP_REQUEST: UInt32 = 13
INTERNET_HANDLE_TYPE_FILE_REQUEST: UInt32 = 14
AUTH_FLAG_DISABLE_NEGOTIATE: UInt32 = 1
AUTH_FLAG_ENABLE_NEGOTIATE: UInt32 = 2
AUTH_FLAG_DISABLE_BASIC_CLEARCHANNEL: UInt32 = 4
AUTH_FLAG_DISABLE_SERVER_AUTH: UInt32 = 8
SECURITY_FLAG_UNKNOWNBIT: UInt32 = 2147483648
SECURITY_FLAG_FORTEZZA: UInt32 = 134217728
SECURITY_FLAG_NORMALBITNESS: UInt32 = 268435456
SECURITY_FLAG_SSL: UInt32 = 2
SECURITY_FLAG_SSL3: UInt32 = 4
SECURITY_FLAG_PCT: UInt32 = 8
SECURITY_FLAG_PCT4: UInt32 = 16
SECURITY_FLAG_IETFSSL4: UInt32 = 32
SECURITY_FLAG_40BIT: UInt32 = 268435456
SECURITY_FLAG_128BIT: UInt32 = 536870912
SECURITY_FLAG_56BIT: UInt32 = 1073741824
SECURITY_FLAG_IGNORE_REVOCATION: UInt32 = 128
SECURITY_FLAG_IGNORE_WRONG_USAGE: UInt32 = 512
SECURITY_FLAG_IGNORE_REDIRECT_TO_HTTPS: UInt32 = 16384
SECURITY_FLAG_IGNORE_REDIRECT_TO_HTTP: UInt32 = 32768
SECURITY_FLAG_IGNORE_WEAK_SIGNATURE: UInt32 = 65536
SECURITY_FLAG_OPT_IN_WEAK_SIGNATURE: UInt32 = 131072
AUTODIAL_MODE_NEVER: UInt32 = 1
AUTODIAL_MODE_ALWAYS: UInt32 = 2
AUTODIAL_MODE_NO_NETWORK_PRESENT: UInt32 = 4
INTERNET_STATUS_RESOLVING_NAME: UInt32 = 10
INTERNET_STATUS_NAME_RESOLVED: UInt32 = 11
INTERNET_STATUS_CONNECTING_TO_SERVER: UInt32 = 20
INTERNET_STATUS_CONNECTED_TO_SERVER: UInt32 = 21
INTERNET_STATUS_SENDING_REQUEST: UInt32 = 30
INTERNET_STATUS_REQUEST_SENT: UInt32 = 31
INTERNET_STATUS_RECEIVING_RESPONSE: UInt32 = 40
INTERNET_STATUS_RESPONSE_RECEIVED: UInt32 = 41
INTERNET_STATUS_CTL_RESPONSE_RECEIVED: UInt32 = 42
INTERNET_STATUS_PREFETCH: UInt32 = 43
INTERNET_STATUS_CLOSING_CONNECTION: UInt32 = 50
INTERNET_STATUS_CONNECTION_CLOSED: UInt32 = 51
INTERNET_STATUS_HANDLE_CREATED: UInt32 = 60
INTERNET_STATUS_HANDLE_CLOSING: UInt32 = 70
INTERNET_STATUS_DETECTING_PROXY: UInt32 = 80
INTERNET_STATUS_REQUEST_COMPLETE: UInt32 = 100
INTERNET_STATUS_REDIRECT: UInt32 = 110
INTERNET_STATUS_INTERMEDIATE_RESPONSE: UInt32 = 120
INTERNET_STATUS_USER_INPUT_REQUIRED: UInt32 = 140
INTERNET_STATUS_STATE_CHANGE: UInt32 = 200
INTERNET_STATUS_COOKIE_SENT: UInt32 = 320
INTERNET_STATUS_COOKIE_RECEIVED: UInt32 = 321
INTERNET_STATUS_PRIVACY_IMPACTED: UInt32 = 324
INTERNET_STATUS_P3P_HEADER: UInt32 = 325
INTERNET_STATUS_P3P_POLICYREF: UInt32 = 326
INTERNET_STATUS_COOKIE_HISTORY: UInt32 = 327
MAX_GOPHER_DISPLAY_TEXT: UInt32 = 128
MAX_GOPHER_SELECTOR_TEXT: UInt32 = 256
MAX_GOPHER_HOST_NAME: UInt32 = 256
MAX_GOPHER_CATEGORY_NAME: UInt32 = 128
MAX_GOPHER_ATTRIBUTE_NAME: UInt32 = 128
MIN_GOPHER_ATTRIBUTE_LENGTH: UInt32 = 256
GOPHER_INFO_CATEGORY: String = '+INFO'
GOPHER_ADMIN_CATEGORY: String = '+ADMIN'
GOPHER_VIEWS_CATEGORY: String = '+VIEWS'
GOPHER_ABSTRACT_CATEGORY: String = '+ABSTRACT'
GOPHER_VERONICA_CATEGORY: String = '+VERONICA'
GOPHER_ADMIN_ATTRIBUTE: String = 'Admin'
GOPHER_MOD_DATE_ATTRIBUTE: String = 'Mod-Date'
GOPHER_TTL_ATTRIBUTE: String = 'TTL'
GOPHER_SCORE_ATTRIBUTE: String = 'Score'
GOPHER_RANGE_ATTRIBUTE: String = 'Score-range'
GOPHER_SITE_ATTRIBUTE: String = 'Site'
GOPHER_ORG_ATTRIBUTE: String = 'Org'
GOPHER_LOCATION_ATTRIBUTE: String = 'Loc'
GOPHER_GEOG_ATTRIBUTE: String = 'Geog'
GOPHER_TIMEZONE_ATTRIBUTE: String = 'TZ'
GOPHER_PROVIDER_ATTRIBUTE: String = 'Provider'
GOPHER_VERSION_ATTRIBUTE: String = 'Version'
GOPHER_ABSTRACT_ATTRIBUTE: String = 'Abstract'
GOPHER_VIEW_ATTRIBUTE: String = 'View'
GOPHER_TREEWALK_ATTRIBUTE: String = 'treewalk'
GOPHER_ATTRIBUTE_ID_BASE: UInt32 = 2882325504
GOPHER_CATEGORY_ID_ALL: UInt32 = 2882325505
GOPHER_CATEGORY_ID_INFO: UInt32 = 2882325506
GOPHER_CATEGORY_ID_ADMIN: UInt32 = 2882325507
GOPHER_CATEGORY_ID_VIEWS: UInt32 = 2882325508
GOPHER_CATEGORY_ID_ABSTRACT: UInt32 = 2882325509
GOPHER_CATEGORY_ID_VERONICA: UInt32 = 2882325510
GOPHER_CATEGORY_ID_ASK: UInt32 = 2882325511
GOPHER_CATEGORY_ID_UNKNOWN: UInt32 = 2882325512
GOPHER_ATTRIBUTE_ID_ALL: UInt32 = 2882325513
GOPHER_ATTRIBUTE_ID_ADMIN: UInt32 = 2882325514
GOPHER_ATTRIBUTE_ID_MOD_DATE: UInt32 = 2882325515
GOPHER_ATTRIBUTE_ID_TTL: UInt32 = 2882325516
GOPHER_ATTRIBUTE_ID_SCORE: UInt32 = 2882325517
GOPHER_ATTRIBUTE_ID_RANGE: UInt32 = 2882325518
GOPHER_ATTRIBUTE_ID_SITE: UInt32 = 2882325519
GOPHER_ATTRIBUTE_ID_ORG: UInt32 = 2882325520
GOPHER_ATTRIBUTE_ID_LOCATION: UInt32 = 2882325521
GOPHER_ATTRIBUTE_ID_GEOG: UInt32 = 2882325522
GOPHER_ATTRIBUTE_ID_TIMEZONE: UInt32 = 2882325523
GOPHER_ATTRIBUTE_ID_PROVIDER: UInt32 = 2882325524
GOPHER_ATTRIBUTE_ID_VERSION: UInt32 = 2882325525
GOPHER_ATTRIBUTE_ID_ABSTRACT: UInt32 = 2882325526
GOPHER_ATTRIBUTE_ID_VIEW: UInt32 = 2882325527
GOPHER_ATTRIBUTE_ID_TREEWALK: UInt32 = 2882325528
GOPHER_ATTRIBUTE_ID_UNKNOWN: UInt32 = 2882325529
HTTP_MAJOR_VERSION: UInt32 = 1
HTTP_MINOR_VERSION: UInt32 = 0
HTTP_VERSIONA: String = 'HTTP/1.0'
HTTP_VERSIONW: String = 'HTTP/1.0'
HTTP_QUERY_MIME_VERSION: UInt32 = 0
HTTP_QUERY_CONTENT_TYPE: UInt32 = 1
HTTP_QUERY_CONTENT_TRANSFER_ENCODING: UInt32 = 2
HTTP_QUERY_CONTENT_ID: UInt32 = 3
HTTP_QUERY_CONTENT_DESCRIPTION: UInt32 = 4
HTTP_QUERY_CONTENT_LENGTH: UInt32 = 5
HTTP_QUERY_CONTENT_LANGUAGE: UInt32 = 6
HTTP_QUERY_ALLOW: UInt32 = 7
HTTP_QUERY_PUBLIC: UInt32 = 8
HTTP_QUERY_DATE: UInt32 = 9
HTTP_QUERY_EXPIRES: UInt32 = 10
HTTP_QUERY_LAST_MODIFIED: UInt32 = 11
HTTP_QUERY_MESSAGE_ID: UInt32 = 12
HTTP_QUERY_URI: UInt32 = 13
HTTP_QUERY_DERIVED_FROM: UInt32 = 14
HTTP_QUERY_COST: UInt32 = 15
HTTP_QUERY_LINK: UInt32 = 16
HTTP_QUERY_PRAGMA: UInt32 = 17
HTTP_QUERY_VERSION: UInt32 = 18
HTTP_QUERY_STATUS_CODE: UInt32 = 19
HTTP_QUERY_STATUS_TEXT: UInt32 = 20
HTTP_QUERY_RAW_HEADERS: UInt32 = 21
HTTP_QUERY_RAW_HEADERS_CRLF: UInt32 = 22
HTTP_QUERY_CONNECTION: UInt32 = 23
HTTP_QUERY_ACCEPT: UInt32 = 24
HTTP_QUERY_ACCEPT_CHARSET: UInt32 = 25
HTTP_QUERY_ACCEPT_ENCODING: UInt32 = 26
HTTP_QUERY_ACCEPT_LANGUAGE: UInt32 = 27
HTTP_QUERY_AUTHORIZATION: UInt32 = 28
HTTP_QUERY_CONTENT_ENCODING: UInt32 = 29
HTTP_QUERY_FORWARDED: UInt32 = 30
HTTP_QUERY_FROM: UInt32 = 31
HTTP_QUERY_IF_MODIFIED_SINCE: UInt32 = 32
HTTP_QUERY_LOCATION: UInt32 = 33
HTTP_QUERY_ORIG_URI: UInt32 = 34
HTTP_QUERY_REFERER: UInt32 = 35
HTTP_QUERY_RETRY_AFTER: UInt32 = 36
HTTP_QUERY_SERVER: UInt32 = 37
HTTP_QUERY_TITLE: UInt32 = 38
HTTP_QUERY_USER_AGENT: UInt32 = 39
HTTP_QUERY_WWW_AUTHENTICATE: UInt32 = 40
HTTP_QUERY_PROXY_AUTHENTICATE: UInt32 = 41
HTTP_QUERY_ACCEPT_RANGES: UInt32 = 42
HTTP_QUERY_SET_COOKIE: UInt32 = 43
HTTP_QUERY_COOKIE: UInt32 = 44
HTTP_QUERY_REQUEST_METHOD: UInt32 = 45
HTTP_QUERY_REFRESH: UInt32 = 46
HTTP_QUERY_CONTENT_DISPOSITION: UInt32 = 47
HTTP_QUERY_AGE: UInt32 = 48
HTTP_QUERY_CACHE_CONTROL: UInt32 = 49
HTTP_QUERY_CONTENT_BASE: UInt32 = 50
HTTP_QUERY_CONTENT_LOCATION: UInt32 = 51
HTTP_QUERY_CONTENT_MD5: UInt32 = 52
HTTP_QUERY_CONTENT_RANGE: UInt32 = 53
HTTP_QUERY_ETAG: UInt32 = 54
HTTP_QUERY_HOST: UInt32 = 55
HTTP_QUERY_IF_MATCH: UInt32 = 56
HTTP_QUERY_IF_NONE_MATCH: UInt32 = 57
HTTP_QUERY_IF_RANGE: UInt32 = 58
HTTP_QUERY_IF_UNMODIFIED_SINCE: UInt32 = 59
HTTP_QUERY_MAX_FORWARDS: UInt32 = 60
HTTP_QUERY_PROXY_AUTHORIZATION: UInt32 = 61
HTTP_QUERY_RANGE: UInt32 = 62
HTTP_QUERY_TRANSFER_ENCODING: UInt32 = 63
HTTP_QUERY_UPGRADE: UInt32 = 64
HTTP_QUERY_VARY: UInt32 = 65
HTTP_QUERY_VIA: UInt32 = 66
HTTP_QUERY_WARNING: UInt32 = 67
HTTP_QUERY_EXPECT: UInt32 = 68
HTTP_QUERY_PROXY_CONNECTION: UInt32 = 69
HTTP_QUERY_UNLESS_MODIFIED_SINCE: UInt32 = 70
HTTP_QUERY_ECHO_REQUEST: UInt32 = 71
HTTP_QUERY_ECHO_REPLY: UInt32 = 72
HTTP_QUERY_ECHO_HEADERS: UInt32 = 73
HTTP_QUERY_ECHO_HEADERS_CRLF: UInt32 = 74
HTTP_QUERY_PROXY_SUPPORT: UInt32 = 75
HTTP_QUERY_AUTHENTICATION_INFO: UInt32 = 76
HTTP_QUERY_PASSPORT_URLS: UInt32 = 77
HTTP_QUERY_PASSPORT_CONFIG: UInt32 = 78
HTTP_QUERY_X_CONTENT_TYPE_OPTIONS: UInt32 = 79
HTTP_QUERY_P3P: UInt32 = 80
HTTP_QUERY_X_P2P_PEERDIST: UInt32 = 81
HTTP_QUERY_TRANSLATE: UInt32 = 82
HTTP_QUERY_X_UA_COMPATIBLE: UInt32 = 83
HTTP_QUERY_DEFAULT_STYLE: UInt32 = 84
HTTP_QUERY_X_FRAME_OPTIONS: UInt32 = 85
HTTP_QUERY_X_XSS_PROTECTION: UInt32 = 86
HTTP_QUERY_SET_COOKIE2: UInt32 = 87
HTTP_QUERY_DO_NOT_TRACK: UInt32 = 88
HTTP_QUERY_KEEP_ALIVE: UInt32 = 89
HTTP_QUERY_HTTP2_SETTINGS: UInt32 = 90
HTTP_QUERY_STRICT_TRANSPORT_SECURITY: UInt32 = 91
HTTP_QUERY_TOKEN_BINDING: UInt32 = 92
HTTP_QUERY_INCLUDE_REFERRED_TOKEN_BINDING_ID: UInt32 = 93
HTTP_QUERY_INCLUDE_REFERER_TOKEN_BINDING_ID: UInt32 = 93
HTTP_QUERY_PUBLIC_KEY_PINS: UInt32 = 94
HTTP_QUERY_PUBLIC_KEY_PINS_REPORT_ONLY: UInt32 = 95
HTTP_QUERY_MAX: UInt32 = 95
HTTP_QUERY_CUSTOM: UInt32 = 65535
HTTP_QUERY_FLAG_REQUEST_HEADERS: UInt32 = 2147483648
HTTP_QUERY_FLAG_SYSTEMTIME: UInt32 = 1073741824
HTTP_QUERY_FLAG_NUMBER: UInt32 = 536870912
HTTP_QUERY_FLAG_COALESCE: UInt32 = 268435456
HTTP_QUERY_FLAG_NUMBER64: UInt32 = 134217728
HTTP_QUERY_FLAG_COALESCE_WITH_COMMA: UInt32 = 67108864
HTTP_STATUS_MISDIRECTED_REQUEST: UInt32 = 421
HTTP_ADDREQ_INDEX_MASK: UInt32 = 65535
HTTP_ADDREQ_FLAGS_MASK: UInt32 = 4294901760
HSR_ASYNC: UInt32 = 1
HSR_SYNC: UInt32 = 4
HSR_USE_CONTEXT: UInt32 = 8
HSR_INITIATE: UInt32 = 8
HSR_DOWNLOAD: UInt32 = 16
HSR_CHUNKED: UInt32 = 32
INTERNET_COOKIE_IS_SECURE: UInt32 = 1
INTERNET_COOKIE_IS_SESSION: UInt32 = 2
INTERNET_COOKIE_PROMPT_REQUIRED: UInt32 = 32
INTERNET_COOKIE_EVALUATE_P3P: UInt32 = 64
INTERNET_COOKIE_APPLY_P3P: UInt32 = 128
INTERNET_COOKIE_P3P_ENABLED: UInt32 = 256
INTERNET_COOKIE_IS_RESTRICTED: UInt32 = 512
INTERNET_COOKIE_IE6: UInt32 = 1024
INTERNET_COOKIE_IS_LEGACY: UInt32 = 2048
INTERNET_COOKIE_NON_SCRIPT: UInt32 = 4096
INTERNET_COOKIE_HOST_ONLY: UInt32 = 16384
INTERNET_COOKIE_APPLY_HOST_ONLY: UInt32 = 32768
INTERNET_COOKIE_HOST_ONLY_APPLIED: UInt32 = 524288
INTERNET_COOKIE_SAME_SITE_STRICT: UInt32 = 1048576
INTERNET_COOKIE_SAME_SITE_LAX: UInt32 = 2097152
INTERNET_COOKIE_SAME_SITE_LEVEL_CROSS_SITE: UInt32 = 4194304
FLAG_ICC_FORCE_CONNECTION: UInt32 = 1
FLAGS_ERROR_UI_FILTER_FOR_ERRORS: UInt32 = 1
FLAGS_ERROR_UI_FLAGS_CHANGE_OPTIONS: UInt32 = 2
FLAGS_ERROR_UI_FLAGS_GENERATE_DATA: UInt32 = 4
FLAGS_ERROR_UI_FLAGS_NO_UI: UInt32 = 8
FLAGS_ERROR_UI_SERIALIZE_DIALOGS: UInt32 = 16
INTERNET_ERROR_BASE: UInt32 = 12000
ERROR_INTERNET_OUT_OF_HANDLES: UInt32 = 12001
ERROR_INTERNET_TIMEOUT: UInt32 = 12002
ERROR_INTERNET_EXTENDED_ERROR: UInt32 = 12003
ERROR_INTERNET_INTERNAL_ERROR: UInt32 = 12004
ERROR_INTERNET_INVALID_URL: UInt32 = 12005
ERROR_INTERNET_UNRECOGNIZED_SCHEME: UInt32 = 12006
ERROR_INTERNET_NAME_NOT_RESOLVED: UInt32 = 12007
ERROR_INTERNET_PROTOCOL_NOT_FOUND: UInt32 = 12008
ERROR_INTERNET_INVALID_OPTION: UInt32 = 12009
ERROR_INTERNET_BAD_OPTION_LENGTH: UInt32 = 12010
ERROR_INTERNET_OPTION_NOT_SETTABLE: UInt32 = 12011
ERROR_INTERNET_SHUTDOWN: UInt32 = 12012
ERROR_INTERNET_INCORRECT_USER_NAME: UInt32 = 12013
ERROR_INTERNET_INCORRECT_PASSWORD: UInt32 = 12014
ERROR_INTERNET_LOGIN_FAILURE: UInt32 = 12015
ERROR_INTERNET_INVALID_OPERATION: UInt32 = 12016
ERROR_INTERNET_OPERATION_CANCELLED: UInt32 = 12017
ERROR_INTERNET_INCORRECT_HANDLE_TYPE: UInt32 = 12018
ERROR_INTERNET_INCORRECT_HANDLE_STATE: UInt32 = 12019
ERROR_INTERNET_NOT_PROXY_REQUEST: UInt32 = 12020
ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND: UInt32 = 12021
ERROR_INTERNET_BAD_REGISTRY_PARAMETER: UInt32 = 12022
ERROR_INTERNET_NO_DIRECT_ACCESS: UInt32 = 12023
ERROR_INTERNET_NO_CONTEXT: UInt32 = 12024
ERROR_INTERNET_NO_CALLBACK: UInt32 = 12025
ERROR_INTERNET_REQUEST_PENDING: UInt32 = 12026
ERROR_INTERNET_INCORRECT_FORMAT: UInt32 = 12027
ERROR_INTERNET_ITEM_NOT_FOUND: UInt32 = 12028
ERROR_INTERNET_CANNOT_CONNECT: UInt32 = 12029
ERROR_INTERNET_CONNECTION_ABORTED: UInt32 = 12030
ERROR_INTERNET_CONNECTION_RESET: UInt32 = 12031
ERROR_INTERNET_FORCE_RETRY: UInt32 = 12032
ERROR_INTERNET_INVALID_PROXY_REQUEST: UInt32 = 12033
ERROR_INTERNET_NEED_UI: UInt32 = 12034
ERROR_INTERNET_HANDLE_EXISTS: UInt32 = 12036
ERROR_INTERNET_SEC_CERT_DATE_INVALID: UInt32 = 12037
ERROR_INTERNET_SEC_CERT_CN_INVALID: UInt32 = 12038
ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR: UInt32 = 12039
ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR: UInt32 = 12040
ERROR_INTERNET_MIXED_SECURITY: UInt32 = 12041
ERROR_INTERNET_CHG_POST_IS_NON_SECURE: UInt32 = 12042
ERROR_INTERNET_POST_IS_NON_SECURE: UInt32 = 12043
ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED: UInt32 = 12044
ERROR_INTERNET_INVALID_CA: UInt32 = 12045
ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP: UInt32 = 12046
ERROR_INTERNET_ASYNC_THREAD_FAILED: UInt32 = 12047
ERROR_INTERNET_REDIRECT_SCHEME_CHANGE: UInt32 = 12048
ERROR_INTERNET_DIALOG_PENDING: UInt32 = 12049
ERROR_INTERNET_RETRY_DIALOG: UInt32 = 12050
ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR: UInt32 = 12052
ERROR_INTERNET_INSERT_CDROM: UInt32 = 12053
ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED: UInt32 = 12054
ERROR_INTERNET_SEC_CERT_ERRORS: UInt32 = 12055
ERROR_INTERNET_SEC_CERT_NO_REV: UInt32 = 12056
ERROR_INTERNET_SEC_CERT_REV_FAILED: UInt32 = 12057
ERROR_HTTP_HSTS_REDIRECT_REQUIRED: UInt32 = 12060
ERROR_INTERNET_SEC_CERT_WEAK_SIGNATURE: UInt32 = 12062
ERROR_FTP_TRANSFER_IN_PROGRESS: UInt32 = 12110
ERROR_FTP_DROPPED: UInt32 = 12111
ERROR_FTP_NO_PASSIVE_MODE: UInt32 = 12112
ERROR_GOPHER_PROTOCOL_ERROR: UInt32 = 12130
ERROR_GOPHER_NOT_FILE: UInt32 = 12131
ERROR_GOPHER_DATA_ERROR: UInt32 = 12132
ERROR_GOPHER_END_OF_DATA: UInt32 = 12133
ERROR_GOPHER_INVALID_LOCATOR: UInt32 = 12134
ERROR_GOPHER_INCORRECT_LOCATOR_TYPE: UInt32 = 12135
ERROR_GOPHER_NOT_GOPHER_PLUS: UInt32 = 12136
ERROR_GOPHER_ATTRIBUTE_NOT_FOUND: UInt32 = 12137
ERROR_GOPHER_UNKNOWN_LOCATOR: UInt32 = 12138
ERROR_HTTP_HEADER_NOT_FOUND: UInt32 = 12150
ERROR_HTTP_DOWNLEVEL_SERVER: UInt32 = 12151
ERROR_HTTP_INVALID_SERVER_RESPONSE: UInt32 = 12152
ERROR_HTTP_INVALID_HEADER: UInt32 = 12153
ERROR_HTTP_INVALID_QUERY_REQUEST: UInt32 = 12154
ERROR_HTTP_HEADER_ALREADY_EXISTS: UInt32 = 12155
ERROR_HTTP_REDIRECT_FAILED: UInt32 = 12156
ERROR_HTTP_NOT_REDIRECTED: UInt32 = 12160
ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION: UInt32 = 12161
ERROR_HTTP_COOKIE_DECLINED: UInt32 = 12162
ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION: UInt32 = 12168
ERROR_INTERNET_SECURITY_CHANNEL_ERROR: UInt32 = 12157
ERROR_INTERNET_UNABLE_TO_CACHE_FILE: UInt32 = 12158
ERROR_INTERNET_TCPIP_NOT_INSTALLED: UInt32 = 12159
ERROR_INTERNET_DISCONNECTED: UInt32 = 12163
ERROR_INTERNET_SERVER_UNREACHABLE: UInt32 = 12164
ERROR_INTERNET_PROXY_SERVER_UNREACHABLE: UInt32 = 12165
ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT: UInt32 = 12166
ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT: UInt32 = 12167
ERROR_INTERNET_SEC_INVALID_CERT: UInt32 = 12169
ERROR_INTERNET_SEC_CERT_REVOKED: UInt32 = 12170
ERROR_INTERNET_FAILED_DUETOSECURITYCHECK: UInt32 = 12171
ERROR_INTERNET_NOT_INITIALIZED: UInt32 = 12172
ERROR_INTERNET_NEED_MSN_SSPI_PKG: UInt32 = 12173
ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY: UInt32 = 12174
ERROR_INTERNET_DECODING_FAILED: UInt32 = 12175
ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED_PROXY: UInt32 = 12187
ERROR_INTERNET_SECURE_FAILURE_PROXY: UInt32 = 12188
ERROR_INTERNET_HTTP_PROTOCOL_MISMATCH: UInt32 = 12190
ERROR_INTERNET_GLOBAL_CALLBACK_FAILED: UInt32 = 12191
ERROR_INTERNET_FEATURE_DISABLED: UInt32 = 12192
INTERNET_ERROR_LAST: UInt32 = 12192
NORMAL_CACHE_ENTRY: UInt32 = 1
STICKY_CACHE_ENTRY: UInt32 = 4
EDITED_CACHE_ENTRY: UInt32 = 8
TRACK_OFFLINE_CACHE_ENTRY: UInt32 = 16
TRACK_ONLINE_CACHE_ENTRY: UInt32 = 32
SPARSE_CACHE_ENTRY: UInt32 = 65536
COOKIE_CACHE_ENTRY: UInt32 = 1048576
URLHISTORY_CACHE_ENTRY: UInt32 = 2097152
CACHEGROUP_ATTRIBUTE_GET_ALL: UInt32 = 4294967295
CACHEGROUP_ATTRIBUTE_BASIC: UInt32 = 1
CACHEGROUP_ATTRIBUTE_FLAG: UInt32 = 2
CACHEGROUP_ATTRIBUTE_TYPE: UInt32 = 4
CACHEGROUP_ATTRIBUTE_QUOTA: UInt32 = 8
CACHEGROUP_ATTRIBUTE_GROUPNAME: UInt32 = 16
CACHEGROUP_ATTRIBUTE_STORAGE: UInt32 = 32
CACHEGROUP_FLAG_NONPURGEABLE: UInt32 = 1
CACHEGROUP_FLAG_GIDONLY: UInt32 = 4
CACHEGROUP_FLAG_FLUSHURL_ONDELETE: UInt32 = 2
CACHEGROUP_SEARCH_ALL: UInt32 = 0
CACHEGROUP_SEARCH_BYURL: UInt32 = 1
CACHEGROUP_TYPE_INVALID: UInt32 = 1
GROUPNAME_MAX_LENGTH: UInt32 = 120
GROUP_OWNER_STORAGE_SIZE: UInt32 = 4
CACHE_ENTRY_ATTRIBUTE_FC: UInt32 = 4
CACHE_ENTRY_HITRATE_FC: UInt32 = 16
CACHE_ENTRY_MODTIME_FC: UInt32 = 64
CACHE_ENTRY_EXPTIME_FC: UInt32 = 128
CACHE_ENTRY_ACCTIME_FC: UInt32 = 256
CACHE_ENTRY_SYNCTIME_FC: UInt32 = 512
CACHE_ENTRY_HEADERINFO_FC: UInt32 = 1024
CACHE_ENTRY_EXEMPT_DELTA_FC: UInt32 = 2048
INTERNET_CACHE_GROUP_ADD: UInt32 = 0
INTERNET_CACHE_GROUP_REMOVE: UInt32 = 1
INTERNET_DIAL_FORCE_PROMPT: UInt32 = 8192
INTERNET_DIAL_SHOW_OFFLINE: UInt32 = 16384
INTERNET_DIAL_UNATTENDED: UInt32 = 32768
INTERENT_GOONLINE_REFRESH: UInt32 = 1
INTERENT_GOONLINE_NOPROMPT: UInt32 = 2
INTERENT_GOONLINE_MASK: UInt32 = 3
INTERNET_CUSTOMDIAL_CONNECT: UInt32 = 0
INTERNET_CUSTOMDIAL_UNATTENDED: UInt32 = 1
INTERNET_CUSTOMDIAL_DISCONNECT: UInt32 = 2
INTERNET_CUSTOMDIAL_SHOWOFFLINE: UInt32 = 4
INTERNET_CUSTOMDIAL_SAFE_FOR_UNATTENDED: UInt32 = 1
INTERNET_CUSTOMDIAL_WILL_SUPPLY_STATE: UInt32 = 2
INTERNET_CUSTOMDIAL_CAN_HANGUP: UInt32 = 4
INTERNET_DIALSTATE_DISCONNECTED: UInt32 = 1
INTERNET_IDENTITY_FLAG_PRIVATE_CACHE: UInt32 = 1
INTERNET_IDENTITY_FLAG_SHARED_CACHE: UInt32 = 2
INTERNET_IDENTITY_FLAG_CLEAR_DATA: UInt32 = 4
INTERNET_IDENTITY_FLAG_CLEAR_COOKIES: UInt32 = 8
INTERNET_IDENTITY_FLAG_CLEAR_HISTORY: UInt32 = 16
INTERNET_IDENTITY_FLAG_CLEAR_CONTENT: UInt32 = 32
INTERNET_SUPPRESS_RESET_ALL: UInt32 = 0
INTERNET_SUPPRESS_COOKIE_POLICY: UInt32 = 1
INTERNET_SUPPRESS_COOKIE_POLICY_RESET: UInt32 = 2
PRIVACY_TEMPLATE_NO_COOKIES: UInt32 = 0
PRIVACY_TEMPLATE_HIGH: UInt32 = 1
PRIVACY_TEMPLATE_MEDIUM_HIGH: UInt32 = 2
PRIVACY_TEMPLATE_MEDIUM: UInt32 = 3
PRIVACY_TEMPLATE_MEDIUM_LOW: UInt32 = 4
PRIVACY_TEMPLATE_LOW: UInt32 = 5
PRIVACY_TEMPLATE_CUSTOM: UInt32 = 100
PRIVACY_TEMPLATE_ADVANCED: UInt32 = 101
PRIVACY_TEMPLATE_MAX: UInt32 = 5
PRIVACY_TYPE_FIRST_PARTY: UInt32 = 0
PRIVACY_TYPE_THIRD_PARTY: UInt32 = 1
MAX_CACHE_ENTRY_INFO_SIZE: UInt32 = 4096
INTERNET_REQFLAG_FROM_APP_CACHE: UInt32 = 256
INTERNET_FLAG_BGUPDATE: UInt32 = 8
INTERNET_FLAG_FTP_FOLDER_VIEW: UInt32 = 4
INTERNET_PREFETCH_PROGRESS: UInt32 = 0
INTERNET_PREFETCH_COMPLETE: UInt32 = 1
INTERNET_PREFETCH_ABORTED: UInt32 = 2
ISO_FORCE_OFFLINE: UInt32 = 1
DLG_FLAGS_INVALID_CA: UInt32 = 16777216
DLG_FLAGS_SEC_CERT_CN_INVALID: UInt32 = 33554432
DLG_FLAGS_SEC_CERT_DATE_INVALID: UInt32 = 67108864
DLG_FLAGS_WEAK_SIGNATURE: UInt32 = 2097152
DLG_FLAGS_INSECURE_FALLBACK: UInt32 = 4194304
DLG_FLAGS_SEC_CERT_REV_FAILED: UInt32 = 8388608
INTERNET_SERVICE_URL: UInt32 = 0
INTERNET_OPTION_CONTEXT_VALUE_OLD: UInt32 = 10
INTERNET_OPTION_NET_SPEED: UInt32 = 61
INTERNET_OPTION_SECURITY_CONNECTION_INFO: UInt32 = 66
INTERNET_OPTION_DETECT_POST_SEND: UInt32 = 71
INTERNET_OPTION_DISABLE_NTLM_PREAUTH: UInt32 = 72
INTERNET_OPTION_ORIGINAL_CONNECT_FLAGS: UInt32 = 97
INTERNET_OPTION_CERT_ERROR_FLAGS: UInt32 = 98
INTERNET_OPTION_IGNORE_CERT_ERROR_FLAGS: UInt32 = 99
INTERNET_OPTION_SESSION_START_TIME: UInt32 = 106
INTERNET_OPTION_PROXY_CREDENTIALS: UInt32 = 107
INTERNET_OPTION_EXTENDED_CALLBACKS: UInt32 = 108
INTERNET_OPTION_PROXY_FROM_REQUEST: UInt32 = 109
INTERNET_OPTION_ALLOW_FAILED_CONNECT_CONTENT: UInt32 = 110
INTERNET_OPTION_CACHE_PARTITION: UInt32 = 111
INTERNET_OPTION_AUTODIAL_HWND: UInt32 = 112
INTERNET_OPTION_SERVER_CREDENTIALS: UInt32 = 113
INTERNET_OPTION_WPAD_SLEEP: UInt32 = 114
INTERNET_OPTION_FAIL_ON_CACHE_WRITE_ERROR: UInt32 = 115
INTERNET_OPTION_DOWNLOAD_MODE: UInt32 = 116
INTERNET_OPTION_RESPONSE_RESUMABLE: UInt32 = 117
INTERNET_OPTION_CM_HANDLE_COPY_REF: UInt32 = 118
INTERNET_OPTION_CONNECTION_INFO: UInt32 = 120
INTERNET_OPTION_BACKGROUND_CONNECTIONS: UInt32 = 121
INTERNET_OPTION_DO_NOT_TRACK: UInt32 = 123
INTERNET_OPTION_USE_MODIFIED_HEADER_FILTER: UInt32 = 124
INTERNET_OPTION_WWA_MODE: UInt32 = 125
INTERNET_OPTION_UPGRADE_TO_WEB_SOCKET: UInt32 = 126
INTERNET_OPTION_WEB_SOCKET_KEEPALIVE_INTERVAL: UInt32 = 127
INTERNET_OPTION_UNLOAD_NOTIFY_EVENT: UInt32 = 128
INTERNET_OPTION_SOCKET_NODELAY: UInt32 = 129
INTERNET_OPTION_APP_CACHE: UInt32 = 130
INTERNET_OPTION_DEPENDENCY_HANDLE: UInt32 = 131
INTERNET_OPTION_USE_FIRST_AVAILABLE_CONNECTION: UInt32 = 132
INTERNET_OPTION_TIMED_CONNECTION_LIMIT_BYPASS: UInt32 = 133
INTERNET_OPTION_WEB_SOCKET_CLOSE_TIMEOUT: UInt32 = 134
INTERNET_OPTION_FLUSH_STATE: UInt32 = 135
INTERNET_OPTION_DISALLOW_PREMATURE_EOF: UInt32 = 137
INTERNET_OPTION_SOCKET_NOTIFICATION_IOCTL: UInt32 = 138
INTERNET_OPTION_CACHE_ENTRY_EXTRA_DATA: UInt32 = 139
INTERNET_OPTION_MAX_QUERY_BUFFER_SIZE: UInt32 = 140
INTERNET_OPTION_FALSE_START: UInt32 = 141
INTERNET_OPTION_USER_PASS_SERVER_ONLY: UInt32 = 142
INTERNET_OPTION_SERVER_AUTH_SCHEME: UInt32 = 143
INTERNET_OPTION_PROXY_AUTH_SCHEME: UInt32 = 144
INTERNET_OPTION_TUNNEL_ONLY: UInt32 = 145
INTERNET_OPTION_SOURCE_PORT: UInt32 = 146
INTERNET_OPTION_ENABLE_DUO: UInt32 = 148
INTERNET_OPTION_DUO_USED: UInt32 = 149
INTERNET_OPTION_CHUNK_ENCODE_REQUEST: UInt32 = 150
INTERNET_OPTION_SECURE_FAILURE: UInt32 = 151
INTERNET_OPTION_NOTIFY_SENDING_COOKIE: UInt32 = 152
INTERNET_OPTION_CLIENT_CERT_ISSUER_LIST: UInt32 = 153
INTERNET_OPTION_RESET: UInt32 = 154
INTERNET_OPTION_SERVER_ADDRESS_INFO: UInt32 = 156
INTERNET_OPTION_ENABLE_WBOEXT: UInt32 = 158
INTERNET_OPTION_DISABLE_INSECURE_FALLBACK: UInt32 = 160
INTERNET_OPTION_ALLOW_INSECURE_FALLBACK: UInt32 = 161
INTERNET_OPTION_SET_IN_PRIVATE: UInt32 = 164
INTERNET_OPTION_DOWNLOAD_MODE_HANDLE: UInt32 = 165
INTERNET_OPTION_EDGE_COOKIES: UInt32 = 166
INTERNET_OPTION_NO_HTTP_SERVER_AUTH: UInt32 = 167
INTERNET_OPTION_ENABLE_HEADER_CALLBACKS: UInt32 = 168
INTERNET_OPTION_PRESERVE_REQUEST_SERVER_CREDENTIALS_ON_REDIRECT: UInt32 = 169
INTERNET_OPTION_PRESERVE_REFERER_ON_HTTPS_TO_HTTP_REDIRECT: UInt32 = 170
INTERNET_OPTION_TCP_FAST_OPEN: UInt32 = 171
INTERNET_OPTION_SYNC_MODE_AUTOMATIC_SESSION_DISABLED: UInt32 = 172
INTERNET_OPTION_ENABLE_ZLIB_DEFLATE: UInt32 = 173
INTERNET_OPTION_ENCODE_FALLBACK_FOR_REDIRECT_URI: UInt32 = 174
INTERNET_OPTION_EDGE_COOKIES_TEMP: UInt32 = 175
INTERNET_OPTION_OPT_IN_WEAK_SIGNATURE: UInt32 = 176
INTERNET_OPTION_PARSE_LINE_FOLDING: UInt32 = 177
INTERNET_OPTION_FORCE_DECODE: UInt32 = 178
INTERNET_OPTION_COOKIES_APPLY_HOST_ONLY: UInt32 = 179
INTERNET_OPTION_EDGE_MODE: UInt32 = 180
INTERNET_OPTION_CANCEL_CACHE_WRITE: UInt32 = 182
INTERNET_OPTION_AUTH_SCHEME_SELECTED: UInt32 = 183
INTERNET_OPTION_NOCACHE_WRITE_IN_PRIVATE: UInt32 = 184
INTERNET_OPTION_ACTIVITY_ID: UInt32 = 185
INTERNET_OPTION_REQUEST_TIMES: UInt32 = 186
INTERNET_OPTION_GLOBAL_CALLBACK: UInt32 = 188
INTERNET_OPTION_ENABLE_TEST_SIGNING: UInt32 = 189
INTERNET_OPTION_DISABLE_PROXY_LINK_LOCAL_NAME_RESOLUTION: UInt32 = 190
INTERNET_OPTION_HTTP_09: UInt32 = 191
INTERNET_OPTION_CALLER_MODULE: UInt32 = 192
INTERNET_LAST_OPTION_INTERNAL: UInt32 = 193
INTERNET_OPTION_OFFLINE_TIMEOUT: UInt32 = 49
INTERNET_OPTION_LINE_STATE: UInt32 = 50
DUO_PROTOCOL_FLAG_SPDY3: UInt32 = 1
DUO_PROTOCOL_MASK: UInt32 = 1
AUTH_FLAG_RESET: UInt32 = 0
INTERNET_AUTH_SCHEME_BASIC: UInt32 = 0
INTERNET_AUTH_SCHEME_DIGEST: UInt32 = 1
INTERNET_AUTH_SCHEME_NTLM: UInt32 = 2
INTERNET_AUTH_SCHEME_KERBEROS: UInt32 = 3
INTERNET_AUTH_SCHEME_NEGOTIATE: UInt32 = 4
INTERNET_AUTH_SCHEME_PASSPORT: UInt32 = 5
INTERNET_AUTH_SCHEME_UNKNOWN: UInt32 = 6
INTERNET_STATUS_SENDING_COOKIE: UInt32 = 328
INTERNET_STATUS_REQUEST_HEADERS_SET: UInt32 = 329
INTERNET_STATUS_RESPONSE_HEADERS_SET: UInt32 = 330
INTERNET_STATUS_PROXY_CREDENTIALS: UInt32 = 400
INTERNET_STATUS_SERVER_CREDENTIALS: UInt32 = 401
INTERNET_STATUS_SERVER_CONNECTION_STATE: UInt32 = 410
INTERNET_STATUS_END_BROWSER_SESSION: UInt32 = 420
INTERNET_STATUS_COOKIE: UInt32 = 430
COOKIE_STATE_LB: UInt32 = 0
COOKIE_STATE_UB: UInt32 = 5
MaxPrivacySettings: UInt32 = 16384
INTERNET_STATUS_FILTER_RESOLVING: UInt32 = 1
INTERNET_STATUS_FILTER_RESOLVED: UInt32 = 2
INTERNET_STATUS_FILTER_CONNECTING: UInt32 = 4
INTERNET_STATUS_FILTER_CONNECTED: UInt32 = 8
INTERNET_STATUS_FILTER_SENDING: UInt32 = 16
INTERNET_STATUS_FILTER_SENT: UInt32 = 32
INTERNET_STATUS_FILTER_RECEIVING: UInt32 = 64
INTERNET_STATUS_FILTER_RECEIVED: UInt32 = 128
INTERNET_STATUS_FILTER_CLOSING: UInt32 = 256
INTERNET_STATUS_FILTER_CLOSED: UInt32 = 512
INTERNET_STATUS_FILTER_HANDLE_CREATED: UInt32 = 1024
INTERNET_STATUS_FILTER_HANDLE_CLOSING: UInt32 = 2048
INTERNET_STATUS_FILTER_PREFETCH: UInt32 = 4096
INTERNET_STATUS_FILTER_REDIRECT: UInt32 = 8192
INTERNET_STATUS_FILTER_STATE_CHANGE: UInt32 = 16384
HTTP_ADDREQ_FLAG_RESPONSE_HEADERS: UInt32 = 33554432
HTTP_ADDREQ_FLAG_ALLOW_EMPTY_VALUES: UInt32 = 67108864
COOKIE_DONT_ALLOW: UInt32 = 1
COOKIE_ALLOW: UInt32 = 2
COOKIE_ALLOW_ALL: UInt32 = 4
COOKIE_DONT_ALLOW_ALL: UInt32 = 8
COOKIE_OP_SET: UInt32 = 1
COOKIE_OP_MODIFY: UInt32 = 2
COOKIE_OP_GET: UInt32 = 4
COOKIE_OP_SESSION: UInt32 = 8
COOKIE_OP_PERSISTENT: UInt32 = 16
COOKIE_OP_3RD_PARTY: UInt32 = 32
INTERNET_COOKIE_PERSISTENT_HOST_ONLY: UInt32 = 65536
INTERNET_COOKIE_RESTRICTED_ZONE: UInt32 = 131072
INTERNET_COOKIE_EDGE_COOKIES: UInt32 = 262144
INTERNET_COOKIE_ALL_COOKIES: UInt32 = 536870912
INTERNET_COOKIE_NO_CALLBACK: UInt32 = 1073741824
INTERNET_COOKIE_ECTX_3RDPARTY: UInt32 = 2147483648
FLAGS_ERROR_UI_SHOW_IDN_HOSTNAME: UInt32 = 32
ERROR_INTERNET_NO_NEW_CONTAINERS: UInt32 = 12051
ERROR_INTERNET_SOURCE_PORT_IN_USE: UInt32 = 12058
ERROR_INTERNET_INSECURE_FALLBACK_REQUIRED: UInt32 = 12059
ERROR_INTERNET_PROXY_ALERT: UInt32 = 12061
ERROR_INTERNET_NO_CM_CONNECTION: UInt32 = 12080
ERROR_HTTP_PUSH_STATUS_CODE_NOT_SUPPORTED: UInt32 = 12147
ERROR_HTTP_PUSH_RETRY_NOT_SUPPORTED: UInt32 = 12148
ERROR_HTTP_PUSH_ENABLE_FAILED: UInt32 = 12149
ERROR_INTERNET_DISALLOW_INPRIVATE: UInt32 = 12189
ERROR_INTERNET_OFFLINE: UInt32 = 12163
INTERNET_INTERNAL_ERROR_BASE: UInt32 = 12900
ERROR_INTERNET_INTERNAL_SOCKET_ERROR: UInt32 = 12901
ERROR_INTERNET_CONNECTION_AVAILABLE: UInt32 = 12902
ERROR_INTERNET_NO_KNOWN_SERVERS: UInt32 = 12903
ERROR_INTERNET_PING_FAILED: UInt32 = 12904
ERROR_INTERNET_NO_PING_SUPPORT: UInt32 = 12905
ERROR_INTERNET_CACHE_SUCCESS: UInt32 = 12906
ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION_EX: UInt32 = 12907
HTTP_1_1_CACHE_ENTRY: UInt32 = 64
STATIC_CACHE_ENTRY: UInt32 = 128
MUST_REVALIDATE_CACHE_ENTRY: UInt32 = 256
SHORTPATH_CACHE_ENTRY: UInt32 = 512
DOWNLOAD_CACHE_ENTRY: UInt32 = 1024
REDIRECT_CACHE_ENTRY: UInt32 = 2048
COOKIE_ACCEPTED_CACHE_ENTRY: UInt32 = 4096
COOKIE_LEASHED_CACHE_ENTRY: UInt32 = 8192
COOKIE_DOWNGRADED_CACHE_ENTRY: UInt32 = 16384
COOKIE_REJECTED_CACHE_ENTRY: UInt32 = 32768
PRIVACY_MODE_CACHE_ENTRY: UInt32 = 131072
XDR_CACHE_ENTRY: UInt32 = 262144
IMMUTABLE_CACHE_ENTRY: UInt32 = 524288
PENDING_DELETE_CACHE_ENTRY: UInt32 = 4194304
OTHER_USER_CACHE_ENTRY: UInt32 = 8388608
PRIVACY_IMPACTED_CACHE_ENTRY: UInt32 = 33554432
POST_RESPONSE_CACHE_ENTRY: UInt32 = 67108864
INSTALLED_CACHE_ENTRY: UInt32 = 268435456
POST_CHECK_CACHE_ENTRY: UInt32 = 536870912
IDENTITY_CACHE_ENTRY: UInt32 = 2147483648
ANY_CACHE_ENTRY: UInt32 = 4294967295
CACHEGROUP_FLAG_VALID: UInt32 = 7
CACHEGROUP_ID_BUILTIN_STICKY: UInt64 = 1152921504606846983
INTERNET_CACHE_FLAG_ALLOW_COLLISIONS: UInt32 = 256
INTERNET_CACHE_FLAG_INSTALLED_ENTRY: UInt32 = 512
INTERNET_CACHE_FLAG_ENTRY_OR_MAPPING: UInt32 = 1024
INTERNET_CACHE_FLAG_ADD_FILENAME_ONLY: UInt32 = 2048
INTERNET_CACHE_FLAG_GET_STRUCT_ONLY: UInt32 = 4096
CACHE_ENTRY_TYPE_FC: UInt32 = 4096
CACHE_ENTRY_MODIFY_DATA_FC: UInt32 = 2147483648
INTERNET_CACHE_CONTAINER_NOSUBDIRS: UInt32 = 1
INTERNET_CACHE_CONTAINER_AUTODELETE: UInt32 = 2
INTERNET_CACHE_CONTAINER_RESERVED1: UInt32 = 4
INTERNET_CACHE_CONTAINER_NODESKTOPINIT: UInt32 = 8
INTERNET_CACHE_CONTAINER_MAP_ENABLED: UInt32 = 16
INTERNET_CACHE_CONTAINER_BLOOM_FILTER: UInt32 = 32
INTERNET_CACHE_CONTAINER_SHARE_READ: UInt32 = 256
INTERNET_CACHE_CONTAINER_SHARE_READ_WRITE: UInt32 = 768
CACHE_FIND_CONTAINER_RETURN_NOCHANGE: UInt32 = 1
CACHE_HEADER_DATA_CURRENT_SETTINGS_VERSION: UInt32 = 0
CACHE_HEADER_DATA_CONLIST_CHANGE_COUNT: UInt32 = 1
CACHE_HEADER_DATA_COOKIE_CHANGE_COUNT: UInt32 = 2
CACHE_HEADER_DATA_NOTIFICATION_HWND: UInt32 = 3
CACHE_HEADER_DATA_NOTIFICATION_MESG: UInt32 = 4
CACHE_HEADER_DATA_ROOTGROUP_OFFSET: UInt32 = 5
CACHE_HEADER_DATA_GID_LOW: UInt32 = 6
CACHE_HEADER_DATA_GID_HIGH: UInt32 = 7
CACHE_HEADER_DATA_LAST_SCAVENGE_TIMESTAMP: UInt32 = 8
CACHE_HEADER_DATA_CACHE_READ_COUNT_SINCE_LAST_SCAVENGE: UInt32 = 9
CACHE_HEADER_DATA_CACHE_WRITE_COUNT_SINCE_LAST_SCAVENGE: UInt32 = 10
CACHE_HEADER_DATA_HSTS_CHANGE_COUNT: UInt32 = 11
CACHE_HEADER_DATA_CACHE_RESERVED_12: UInt32 = 12
CACHE_HEADER_DATA_CACHE_RESERVED_13: UInt32 = 13
CACHE_HEADER_DATA_SSL_STATE_COUNT: UInt32 = 14
CACHE_HEADER_DATA_DOWNLOAD_PARTIAL: UInt32 = 14
CACHE_HEADER_DATA_CACHE_RESERVED_15: UInt32 = 15
CACHE_HEADER_DATA_CACHE_RESERVED_16: UInt32 = 16
CACHE_HEADER_DATA_CACHE_RESERVED_17: UInt32 = 17
CACHE_HEADER_DATA_CACHE_RESERVED_18: UInt32 = 18
CACHE_HEADER_DATA_CACHE_RESERVED_19: UInt32 = 19
CACHE_HEADER_DATA_CACHE_RESERVED_20: UInt32 = 20
CACHE_HEADER_DATA_NOTIFICATION_FILTER: UInt32 = 21
CACHE_HEADER_DATA_ROOT_LEAK_OFFSET: UInt32 = 22
CACHE_HEADER_DATA_CACHE_RESERVED_23: UInt32 = 23
CACHE_HEADER_DATA_CACHE_RESERVED_24: UInt32 = 24
CACHE_HEADER_DATA_CACHE_RESERVED_25: UInt32 = 25
CACHE_HEADER_DATA_CACHE_RESERVED_26: UInt32 = 26
CACHE_HEADER_DATA_ROOT_GROUPLIST_OFFSET: UInt32 = 27
CACHE_HEADER_DATA_CACHE_RESERVED_28: UInt32 = 28
CACHE_HEADER_DATA_CACHE_RESERVED_29: UInt32 = 29
CACHE_HEADER_DATA_CACHE_RESERVED_30: UInt32 = 30
CACHE_HEADER_DATA_CACHE_RESERVED_31: UInt32 = 31
CACHE_HEADER_DATA_LAST: UInt32 = 31
CACHE_NOTIFY_ADD_URL: UInt32 = 1
CACHE_NOTIFY_DELETE_URL: UInt32 = 2
CACHE_NOTIFY_UPDATE_URL: UInt32 = 4
CACHE_NOTIFY_DELETE_ALL: UInt32 = 8
CACHE_NOTIFY_URL_SET_STICKY: UInt32 = 16
CACHE_NOTIFY_URL_UNSET_STICKY: UInt32 = 32
CACHE_NOTIFY_SET_ONLINE: UInt32 = 256
CACHE_NOTIFY_SET_OFFLINE: UInt32 = 512
CACHE_NOTIFY_FILTER_CHANGED: UInt32 = 268435456
APP_CACHE_LOOKUP_NO_MASTER_ONLY: UInt32 = 1
APP_CACHE_ENTRY_TYPE_MASTER: UInt32 = 1
APP_CACHE_ENTRY_TYPE_EXPLICIT: UInt32 = 2
APP_CACHE_ENTRY_TYPE_FALLBACK: UInt32 = 4
APP_CACHE_ENTRY_TYPE_FOREIGN: UInt32 = 8
APP_CACHE_ENTRY_TYPE_MANIFEST: UInt32 = 16
CACHE_CONFIG_CONTENT_QUOTA_FC: UInt32 = 32768
CACHE_CONFIG_TOTAL_CONTENT_QUOTA_FC: UInt32 = 65536
CACHE_CONFIG_APPCONTAINER_CONTENT_QUOTA_FC: UInt32 = 131072
CACHE_CONFIG_APPCONTAINER_TOTAL_CONTENT_QUOTA_FC: UInt32 = 262144
INTERNET_AUTOPROXY_INIT_DEFAULT: UInt32 = 1
INTERNET_AUTOPROXY_INIT_DOWNLOADSYNC: UInt32 = 2
INTERNET_AUTOPROXY_INIT_QUERYSTATE: UInt32 = 4
INTERNET_AUTOPROXY_INIT_ONLYQUERY: UInt32 = 8
REGSTR_DIAL_AUTOCONNECT: String = 'AutoConnect'
REGSTR_LEASH_LEGACY_COOKIES: String = 'LeashLegacyCookies'
LOCAL_NAMESPACE_PREFIX: String = 'Local\\'
LOCAL_NAMESPACE_PREFIX_W: String = 'Local\\'
INTERNET_SUPPRESS_COOKIE_PERSIST: UInt32 = 3
INTERNET_SUPPRESS_COOKIE_PERSIST_RESET: UInt32 = 4
HTTP_WEB_SOCKET_MAX_CLOSE_REASON_LENGTH: UInt32 = 123
HTTP_WEB_SOCKET_MIN_KEEPALIVE_VALUE: UInt32 = 10000
INTERNET_GLOBAL_CALLBACK_SENDING_HTTP_HEADERS: UInt32 = 1
INTERNET_GLOBAL_CALLBACK_DETECTING_PROXY: UInt32 = 2
@winfunctype('WININET.dll')
def InternetTimeFromSystemTimeA(pst: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), dwRFC: UInt32, lpszTime: win32more.Windows.Win32.Foundation.PSTR, cbTime: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetTimeFromSystemTimeW(pst: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), dwRFC: UInt32, lpszTime: win32more.Windows.Win32.Foundation.PWSTR, cbTime: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetTimeFromSystemTime = UnicodeAlias('InternetTimeFromSystemTimeW')
@winfunctype('WININET.dll')
def InternetTimeToSystemTimeA(lpszTime: win32more.Windows.Win32.Foundation.PSTR, pst: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetTimeToSystemTimeW(lpszTime: win32more.Windows.Win32.Foundation.PWSTR, pst: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetTimeToSystemTime = UnicodeAlias('InternetTimeToSystemTimeW')
@winfunctype('WININET.dll')
def InternetCrackUrlA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, dwUrlLength: UInt32, dwFlags: win32more.Windows.Win32.Networking.WinHttp.WIN_HTTP_CREATE_URL_FLAGS, lpUrlComponents: POINTER(win32more.Windows.Win32.Networking.WinInet.URL_COMPONENTSA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetCrackUrlW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, dwUrlLength: UInt32, dwFlags: win32more.Windows.Win32.Networking.WinHttp.WIN_HTTP_CREATE_URL_FLAGS, lpUrlComponents: POINTER(win32more.Windows.Win32.Networking.WinInet.URL_COMPONENTSW)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetCrackUrl = UnicodeAlias('InternetCrackUrlW')
@winfunctype('WININET.dll')
def InternetCreateUrlA(lpUrlComponents: POINTER(win32more.Windows.Win32.Networking.WinInet.URL_COMPONENTSA), dwFlags: UInt32, lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpdwUrlLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetCreateUrlW(lpUrlComponents: POINTER(win32more.Windows.Win32.Networking.WinInet.URL_COMPONENTSW), dwFlags: UInt32, lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpdwUrlLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetCreateUrl = UnicodeAlias('InternetCreateUrlW')
@winfunctype('WININET.dll')
def InternetCanonicalizeUrlA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszBuffer: win32more.Windows.Win32.Foundation.PSTR, lpdwBufferLength: POINTER(UInt32), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetCanonicalizeUrlW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszBuffer: win32more.Windows.Win32.Foundation.PWSTR, lpdwBufferLength: POINTER(UInt32), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetCanonicalizeUrl = UnicodeAlias('InternetCanonicalizeUrlW')
@winfunctype('WININET.dll')
def InternetCombineUrlA(lpszBaseUrl: win32more.Windows.Win32.Foundation.PSTR, lpszRelativeUrl: win32more.Windows.Win32.Foundation.PSTR, lpszBuffer: win32more.Windows.Win32.Foundation.PSTR, lpdwBufferLength: POINTER(UInt32), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetCombineUrlW(lpszBaseUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszRelativeUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszBuffer: win32more.Windows.Win32.Foundation.PWSTR, lpdwBufferLength: POINTER(UInt32), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetCombineUrl = UnicodeAlias('InternetCombineUrlW')
@winfunctype('WININET.dll')
def InternetOpenA(lpszAgent: win32more.Windows.Win32.Foundation.PSTR, dwAccessType: UInt32, lpszProxy: win32more.Windows.Win32.Foundation.PSTR, lpszProxyBypass: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32) -> VoidPtr: ...
@winfunctype('WININET.dll')
def InternetOpenW(lpszAgent: win32more.Windows.Win32.Foundation.PWSTR, dwAccessType: UInt32, lpszProxy: win32more.Windows.Win32.Foundation.PWSTR, lpszProxyBypass: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> VoidPtr: ...
InternetOpen = UnicodeAlias('InternetOpenW')
@winfunctype('WININET.dll')
def InternetCloseHandle(hInternet: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetConnectA(hInternet: VoidPtr, lpszServerName: win32more.Windows.Win32.Foundation.PSTR, nServerPort: UInt16, lpszUserName: win32more.Windows.Win32.Foundation.PSTR, lpszPassword: win32more.Windows.Win32.Foundation.PSTR, dwService: UInt32, dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def InternetConnectW(hInternet: VoidPtr, lpszServerName: win32more.Windows.Win32.Foundation.PWSTR, nServerPort: UInt16, lpszUserName: win32more.Windows.Win32.Foundation.PWSTR, lpszPassword: win32more.Windows.Win32.Foundation.PWSTR, dwService: UInt32, dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
InternetConnect = UnicodeAlias('InternetConnectW')
@winfunctype('WININET.dll')
def InternetOpenUrlA(hInternet: VoidPtr, lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszHeaders: win32more.Windows.Win32.Foundation.PSTR, dwHeadersLength: UInt32, dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def InternetOpenUrlW(hInternet: VoidPtr, lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszHeaders: win32more.Windows.Win32.Foundation.PWSTR, dwHeadersLength: UInt32, dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
InternetOpenUrl = UnicodeAlias('InternetOpenUrlW')
@winfunctype('WININET.dll')
def InternetReadFile(hFile: VoidPtr, lpBuffer: VoidPtr, dwNumberOfBytesToRead: UInt32, lpdwNumberOfBytesRead: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetReadFileExA(hFile: VoidPtr, lpBuffersOut: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSA), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetReadFileExW(hFile: VoidPtr, lpBuffersOut: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSW), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetReadFileEx = UnicodeAlias('InternetReadFileExW')
@winfunctype('WININET.dll')
def InternetSetFilePointer(hFile: VoidPtr, lDistanceToMove: Int32, lpDistanceToMoveHigh: POINTER(Int32), dwMoveMethod: UInt32, dwContext: UIntPtr) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetWriteFile(hFile: VoidPtr, lpBuffer: VoidPtr, dwNumberOfBytesToWrite: UInt32, lpdwNumberOfBytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetQueryDataAvailable(hFile: VoidPtr, lpdwNumberOfBytesAvailable: POINTER(UInt32), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetFindNextFileA(hFind: VoidPtr, lpvFindData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetFindNextFileW(hFind: VoidPtr, lpvFindData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetFindNextFile = UnicodeAlias('InternetFindNextFileW')
@winfunctype('WININET.dll')
def InternetQueryOptionA(hInternet: VoidPtr, dwOption: UInt32, lpBuffer: VoidPtr, lpdwBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetQueryOptionW(hInternet: VoidPtr, dwOption: UInt32, lpBuffer: VoidPtr, lpdwBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetQueryOption = UnicodeAlias('InternetQueryOptionW')
@winfunctype('WININET.dll')
def InternetSetOptionA(hInternet: VoidPtr, dwOption: UInt32, lpBuffer: VoidPtr, dwBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetSetOptionW(hInternet: VoidPtr, dwOption: UInt32, lpBuffer: VoidPtr, dwBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetSetOption = UnicodeAlias('InternetSetOptionW')
@winfunctype('WININET.dll')
def InternetSetOptionExA(hInternet: VoidPtr, dwOption: UInt32, lpBuffer: VoidPtr, dwBufferLength: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetSetOptionExW(hInternet: VoidPtr, dwOption: UInt32, lpBuffer: VoidPtr, dwBufferLength: UInt32, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetSetOptionEx = UnicodeAlias('InternetSetOptionExW')
@winfunctype('WININET.dll')
def InternetLockRequestFile(hInternet: VoidPtr, lphLockRequestInfo: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetUnlockRequestFile(hLockRequestInfo: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetLastResponseInfoA(lpdwError: POINTER(UInt32), lpszBuffer: win32more.Windows.Win32.Foundation.PSTR, lpdwBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetLastResponseInfoW(lpdwError: POINTER(UInt32), lpszBuffer: win32more.Windows.Win32.Foundation.PWSTR, lpdwBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetGetLastResponseInfo = UnicodeAlias('InternetGetLastResponseInfoW')
@winfunctype('WININET.dll')
def InternetSetStatusCallbackA(hInternet: VoidPtr, lpfnInternetCallback: win32more.Windows.Win32.Networking.WinInet.LPINTERNET_STATUS_CALLBACK) -> win32more.Windows.Win32.Networking.WinInet.LPINTERNET_STATUS_CALLBACK: ...
@winfunctype('WININET.dll')
def InternetSetStatusCallbackW(hInternet: VoidPtr, lpfnInternetCallback: win32more.Windows.Win32.Networking.WinInet.LPINTERNET_STATUS_CALLBACK) -> win32more.Windows.Win32.Networking.WinInet.LPINTERNET_STATUS_CALLBACK: ...
InternetSetStatusCallback = UnicodeAlias('InternetSetStatusCallbackW')
@winfunctype('WININET.dll')
def FtpFindFirstFileA(hConnect: VoidPtr, lpszSearchFile: win32more.Windows.Win32.Foundation.PSTR, lpFindFileData: POINTER(win32more.Windows.Win32.Storage.FileSystem.WIN32_FIND_DATAA), dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def FtpFindFirstFileW(hConnect: VoidPtr, lpszSearchFile: win32more.Windows.Win32.Foundation.PWSTR, lpFindFileData: POINTER(win32more.Windows.Win32.Storage.FileSystem.WIN32_FIND_DATAW), dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
FtpFindFirstFile = UnicodeAlias('FtpFindFirstFileW')
@winfunctype('WININET.dll')
def FtpGetFileA(hConnect: VoidPtr, lpszRemoteFile: win32more.Windows.Win32.Foundation.PSTR, lpszNewFile: win32more.Windows.Win32.Foundation.PSTR, fFailIfExists: win32more.Windows.Win32.Foundation.BOOL, dwFlagsAndAttributes: UInt32, dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpGetFileW(hConnect: VoidPtr, lpszRemoteFile: win32more.Windows.Win32.Foundation.PWSTR, lpszNewFile: win32more.Windows.Win32.Foundation.PWSTR, fFailIfExists: win32more.Windows.Win32.Foundation.BOOL, dwFlagsAndAttributes: UInt32, dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpGetFile = UnicodeAlias('FtpGetFileW')
@winfunctype('WININET.dll')
def FtpPutFileA(hConnect: VoidPtr, lpszLocalFile: win32more.Windows.Win32.Foundation.PSTR, lpszNewRemoteFile: win32more.Windows.Win32.Foundation.PSTR, dwFlags: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpPutFileW(hConnect: VoidPtr, lpszLocalFile: win32more.Windows.Win32.Foundation.PWSTR, lpszNewRemoteFile: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpPutFile = UnicodeAlias('FtpPutFileW')
@winfunctype('WININET.dll')
def FtpGetFileEx(hFtpSession: VoidPtr, lpszRemoteFile: win32more.Windows.Win32.Foundation.PSTR, lpszNewFile: win32more.Windows.Win32.Foundation.PWSTR, fFailIfExists: win32more.Windows.Win32.Foundation.BOOL, dwFlagsAndAttributes: UInt32, dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpPutFileEx(hFtpSession: VoidPtr, lpszLocalFile: win32more.Windows.Win32.Foundation.PWSTR, lpszNewRemoteFile: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpDeleteFileA(hConnect: VoidPtr, lpszFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpDeleteFileW(hConnect: VoidPtr, lpszFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpDeleteFile = UnicodeAlias('FtpDeleteFileW')
@winfunctype('WININET.dll')
def FtpRenameFileA(hConnect: VoidPtr, lpszExisting: win32more.Windows.Win32.Foundation.PSTR, lpszNew: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpRenameFileW(hConnect: VoidPtr, lpszExisting: win32more.Windows.Win32.Foundation.PWSTR, lpszNew: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpRenameFile = UnicodeAlias('FtpRenameFileW')
@winfunctype('WININET.dll')
def FtpOpenFileA(hConnect: VoidPtr, lpszFileName: win32more.Windows.Win32.Foundation.PSTR, dwAccess: UInt32, dwFlags: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def FtpOpenFileW(hConnect: VoidPtr, lpszFileName: win32more.Windows.Win32.Foundation.PWSTR, dwAccess: UInt32, dwFlags: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS, dwContext: UIntPtr) -> VoidPtr: ...
FtpOpenFile = UnicodeAlias('FtpOpenFileW')
@winfunctype('WININET.dll')
def FtpCreateDirectoryA(hConnect: VoidPtr, lpszDirectory: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpCreateDirectoryW(hConnect: VoidPtr, lpszDirectory: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpCreateDirectory = UnicodeAlias('FtpCreateDirectoryW')
@winfunctype('WININET.dll')
def FtpRemoveDirectoryA(hConnect: VoidPtr, lpszDirectory: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpRemoveDirectoryW(hConnect: VoidPtr, lpszDirectory: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpRemoveDirectory = UnicodeAlias('FtpRemoveDirectoryW')
@winfunctype('WININET.dll')
def FtpSetCurrentDirectoryA(hConnect: VoidPtr, lpszDirectory: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpSetCurrentDirectoryW(hConnect: VoidPtr, lpszDirectory: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpSetCurrentDirectory = UnicodeAlias('FtpSetCurrentDirectoryW')
@winfunctype('WININET.dll')
def FtpGetCurrentDirectoryA(hConnect: VoidPtr, lpszCurrentDirectory: win32more.Windows.Win32.Foundation.PSTR, lpdwCurrentDirectory: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpGetCurrentDirectoryW(hConnect: VoidPtr, lpszCurrentDirectory: win32more.Windows.Win32.Foundation.PWSTR, lpdwCurrentDirectory: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpGetCurrentDirectory = UnicodeAlias('FtpGetCurrentDirectoryW')
@winfunctype('WININET.dll')
def FtpCommandA(hConnect: VoidPtr, fExpectResponse: win32more.Windows.Win32.Foundation.BOOL, dwFlags: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS, lpszCommand: win32more.Windows.Win32.Foundation.PSTR, dwContext: UIntPtr, phFtpCommand: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FtpCommandW(hConnect: VoidPtr, fExpectResponse: win32more.Windows.Win32.Foundation.BOOL, dwFlags: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS, lpszCommand: win32more.Windows.Win32.Foundation.PWSTR, dwContext: UIntPtr, phFtpCommand: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
FtpCommand = UnicodeAlias('FtpCommandW')
@winfunctype('WININET.dll')
def FtpGetFileSize(hFile: VoidPtr, lpdwFileSizeHigh: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def GopherCreateLocatorA(lpszHost: win32more.Windows.Win32.Foundation.PSTR, nServerPort: UInt16, lpszDisplayString: win32more.Windows.Win32.Foundation.PSTR, lpszSelectorString: win32more.Windows.Win32.Foundation.PSTR, dwGopherType: UInt32, lpszLocator: win32more.Windows.Win32.Foundation.PSTR, lpdwBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GopherCreateLocatorW(lpszHost: win32more.Windows.Win32.Foundation.PWSTR, nServerPort: UInt16, lpszDisplayString: win32more.Windows.Win32.Foundation.PWSTR, lpszSelectorString: win32more.Windows.Win32.Foundation.PWSTR, dwGopherType: UInt32, lpszLocator: win32more.Windows.Win32.Foundation.PWSTR, lpdwBufferLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GopherCreateLocator = UnicodeAlias('GopherCreateLocatorW')
@winfunctype('WININET.dll')
def GopherGetLocatorTypeA(lpszLocator: win32more.Windows.Win32.Foundation.PSTR, lpdwGopherType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GopherGetLocatorTypeW(lpszLocator: win32more.Windows.Win32.Foundation.PWSTR, lpdwGopherType: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GopherGetLocatorType = UnicodeAlias('GopherGetLocatorTypeW')
@winfunctype('WININET.dll')
def GopherFindFirstFileA(hConnect: VoidPtr, lpszLocator: win32more.Windows.Win32.Foundation.PSTR, lpszSearchString: win32more.Windows.Win32.Foundation.PSTR, lpFindData: POINTER(win32more.Windows.Win32.Networking.WinInet.GOPHER_FIND_DATAA), dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def GopherFindFirstFileW(hConnect: VoidPtr, lpszLocator: win32more.Windows.Win32.Foundation.PWSTR, lpszSearchString: win32more.Windows.Win32.Foundation.PWSTR, lpFindData: POINTER(win32more.Windows.Win32.Networking.WinInet.GOPHER_FIND_DATAW), dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
GopherFindFirstFile = UnicodeAlias('GopherFindFirstFileW')
@winfunctype('WININET.dll')
def GopherOpenFileA(hConnect: VoidPtr, lpszLocator: win32more.Windows.Win32.Foundation.PSTR, lpszView: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def GopherOpenFileW(hConnect: VoidPtr, lpszLocator: win32more.Windows.Win32.Foundation.PWSTR, lpszView: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
GopherOpenFile = UnicodeAlias('GopherOpenFileW')
@winfunctype('WININET.dll')
def GopherGetAttributeA(hConnect: VoidPtr, lpszLocator: win32more.Windows.Win32.Foundation.PSTR, lpszAttributeName: win32more.Windows.Win32.Foundation.PSTR, lpBuffer: POINTER(Byte), dwBufferLength: UInt32, lpdwCharactersReturned: POINTER(UInt32), lpfnEnumerator: win32more.Windows.Win32.Networking.WinInet.GOPHER_ATTRIBUTE_ENUMERATOR, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GopherGetAttributeW(hConnect: VoidPtr, lpszLocator: win32more.Windows.Win32.Foundation.PWSTR, lpszAttributeName: win32more.Windows.Win32.Foundation.PWSTR, lpBuffer: POINTER(Byte), dwBufferLength: UInt32, lpdwCharactersReturned: POINTER(UInt32), lpfnEnumerator: win32more.Windows.Win32.Networking.WinInet.GOPHER_ATTRIBUTE_ENUMERATOR, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
GopherGetAttribute = UnicodeAlias('GopherGetAttributeW')
@winfunctype('WININET.dll')
def HttpOpenRequestA(hConnect: VoidPtr, lpszVerb: win32more.Windows.Win32.Foundation.PSTR, lpszObjectName: win32more.Windows.Win32.Foundation.PSTR, lpszVersion: win32more.Windows.Win32.Foundation.PSTR, lpszReferrer: win32more.Windows.Win32.Foundation.PSTR, lplpszAcceptTypes: POINTER(win32more.Windows.Win32.Foundation.PSTR), dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def HttpOpenRequestW(hConnect: VoidPtr, lpszVerb: win32more.Windows.Win32.Foundation.PWSTR, lpszObjectName: win32more.Windows.Win32.Foundation.PWSTR, lpszVersion: win32more.Windows.Win32.Foundation.PWSTR, lpszReferrer: win32more.Windows.Win32.Foundation.PWSTR, lplpszAcceptTypes: POINTER(win32more.Windows.Win32.Foundation.PWSTR), dwFlags: UInt32, dwContext: UIntPtr) -> VoidPtr: ...
HttpOpenRequest = UnicodeAlias('HttpOpenRequestW')
@winfunctype('WININET.dll')
def HttpAddRequestHeadersA(hRequest: VoidPtr, lpszHeaders: win32more.Windows.Win32.Foundation.PSTR, dwHeadersLength: UInt32, dwModifiers: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpAddRequestHeadersW(hRequest: VoidPtr, lpszHeaders: win32more.Windows.Win32.Foundation.PWSTR, dwHeadersLength: UInt32, dwModifiers: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG) -> win32more.Windows.Win32.Foundation.BOOL: ...
HttpAddRequestHeaders = UnicodeAlias('HttpAddRequestHeadersW')
@winfunctype('WININET.dll')
def HttpSendRequestA(hRequest: VoidPtr, lpszHeaders: win32more.Windows.Win32.Foundation.PSTR, dwHeadersLength: UInt32, lpOptional: VoidPtr, dwOptionalLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpSendRequestW(hRequest: VoidPtr, lpszHeaders: win32more.Windows.Win32.Foundation.PWSTR, dwHeadersLength: UInt32, lpOptional: VoidPtr, dwOptionalLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
HttpSendRequest = UnicodeAlias('HttpSendRequestW')
@winfunctype('WININET.dll')
def HttpSendRequestExA(hRequest: VoidPtr, lpBuffersIn: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSA), lpBuffersOut: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSA), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpSendRequestExW(hRequest: VoidPtr, lpBuffersIn: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSW), lpBuffersOut: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSW), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
HttpSendRequestEx = UnicodeAlias('HttpSendRequestExW')
@winfunctype('WININET.dll')
def HttpEndRequestA(hRequest: VoidPtr, lpBuffersOut: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSA), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpEndRequestW(hRequest: VoidPtr, lpBuffersOut: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSW), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
HttpEndRequest = UnicodeAlias('HttpEndRequestW')
@winfunctype('WININET.dll')
def HttpQueryInfoA(hRequest: VoidPtr, dwInfoLevel: UInt32, lpBuffer: VoidPtr, lpdwBufferLength: POINTER(UInt32), lpdwIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpQueryInfoW(hRequest: VoidPtr, dwInfoLevel: UInt32, lpBuffer: VoidPtr, lpdwBufferLength: POINTER(UInt32), lpdwIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
HttpQueryInfo = UnicodeAlias('HttpQueryInfoW')
@winfunctype('WININET.dll')
def InternetSetCookieA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetSetCookieW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetSetCookie = UnicodeAlias('InternetSetCookieW')
@winfunctype('WININET.dll')
def InternetGetCookieA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PSTR, lpdwSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetCookieW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PWSTR, lpdwSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetGetCookie = UnicodeAlias('InternetGetCookieW')
@winfunctype('WININET.dll')
def InternetSetCookieExA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, dwReserved: UIntPtr) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetSetCookieExW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, dwReserved: UIntPtr) -> UInt32: ...
InternetSetCookieEx = UnicodeAlias('InternetSetCookieExW')
@winfunctype('WININET.dll')
def InternetGetCookieExA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PSTR, lpdwSize: POINTER(UInt32), dwFlags: win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE_FLAGS, lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetCookieExW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieName: win32more.Windows.Win32.Foundation.PWSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PWSTR, lpdwSize: POINTER(UInt32), dwFlags: win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE_FLAGS, lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetGetCookieEx = UnicodeAlias('InternetGetCookieExW')
@winfunctype('WININET.dll')
def InternetFreeCookies(pCookies: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE2), dwCookieCount: UInt32) -> Void: ...
@winfunctype('WININET.dll')
def InternetGetCookieEx2(pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pcwszCookieName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, ppCookies: POINTER(POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE2)), pdwCookieCount: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetSetCookieEx2(pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pCookie: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE2), pcwszP3PPolicy: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, pdwCookieState: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetAttemptConnect(dwReserved: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetCheckConnectionA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetCheckConnectionW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetCheckConnection = UnicodeAlias('InternetCheckConnectionW')
@winfunctype('WININET.dll')
def ResumeSuspendedDownload(hRequest: VoidPtr, dwResultCode: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetErrorDlg(hWnd: win32more.Windows.Win32.Foundation.HWND, hRequest: VoidPtr, dwError: UInt32, dwFlags: UInt32, lppvData: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetConfirmZoneCrossingA(hWnd: win32more.Windows.Win32.Foundation.HWND, szUrlPrev: win32more.Windows.Win32.Foundation.PSTR, szUrlNew: win32more.Windows.Win32.Foundation.PSTR, bPost: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetConfirmZoneCrossingW(hWnd: win32more.Windows.Win32.Foundation.HWND, szUrlPrev: win32more.Windows.Win32.Foundation.PWSTR, szUrlNew: win32more.Windows.Win32.Foundation.PWSTR, bPost: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
InternetConfirmZoneCrossing = UnicodeAlias('InternetConfirmZoneCrossingW')
@winfunctype('WININET.dll')
def CreateUrlCacheEntryA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, dwExpectedFileSize: UInt32, lpszFileExtension: win32more.Windows.Win32.Foundation.PSTR, lpszFileName: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def CreateUrlCacheEntryW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, dwExpectedFileSize: UInt32, lpszFileExtension: win32more.Windows.Win32.Foundation.PWSTR, lpszFileName: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
CreateUrlCacheEntry = UnicodeAlias('CreateUrlCacheEntryW')
@winfunctype('WININET.dll')
def CommitUrlCacheEntryA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, lpszLocalFileName: win32more.Windows.Win32.Foundation.PSTR, ExpireTime: win32more.Windows.Win32.Foundation.FILETIME, LastModifiedTime: win32more.Windows.Win32.Foundation.FILETIME, CacheEntryType: UInt32, lpHeaderInfo: POINTER(Byte), cchHeaderInfo: UInt32, lpszFileExtension: win32more.Windows.Win32.Foundation.PSTR, lpszOriginalUrl: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def CommitUrlCacheEntryW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, lpszLocalFileName: win32more.Windows.Win32.Foundation.PWSTR, ExpireTime: win32more.Windows.Win32.Foundation.FILETIME, LastModifiedTime: win32more.Windows.Win32.Foundation.FILETIME, CacheEntryType: UInt32, lpszHeaderInfo: win32more.Windows.Win32.Foundation.PWSTR, cchHeaderInfo: UInt32, lpszFileExtension: win32more.Windows.Win32.Foundation.PWSTR, lpszOriginalUrl: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
CommitUrlCacheEntry = UnicodeAlias('CommitUrlCacheEntryW')
@winfunctype('WININET.dll')
def RetrieveUrlCacheEntryFileA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def RetrieveUrlCacheEntryFileW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
RetrieveUrlCacheEntryFile = UnicodeAlias('RetrieveUrlCacheEntryFileW')
@winfunctype('WININET.dll')
def UnlockUrlCacheEntryFileA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def UnlockUrlCacheEntryFileW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
UnlockUrlCacheEntryFile = UnicodeAlias('UnlockUrlCacheEntryFileW')
@winfunctype('WININET.dll')
def RetrieveUrlCacheEntryStreamA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32), fRandomRead: win32more.Windows.Win32.Foundation.BOOL, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('WININET.dll')
def RetrieveUrlCacheEntryStreamW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32), fRandomRead: win32more.Windows.Win32.Foundation.BOOL, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
RetrieveUrlCacheEntryStream = UnicodeAlias('RetrieveUrlCacheEntryStreamW')
@winfunctype('WININET.dll')
def ReadUrlCacheEntryStream(hUrlCacheStream: win32more.Windows.Win32.Foundation.HANDLE, dwLocation: UInt32, lpBuffer: VoidPtr, lpdwLen: POINTER(UInt32), Reserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def ReadUrlCacheEntryStreamEx(hUrlCacheStream: win32more.Windows.Win32.Foundation.HANDLE, qwLocation: UInt64, lpBuffer: VoidPtr, lpdwLen: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def UnlockUrlCacheEntryStream(hUrlCacheStream: win32more.Windows.Win32.Foundation.HANDLE, Reserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheEntryInfoA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheEntryInfoW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetUrlCacheEntryInfo = UnicodeAlias('GetUrlCacheEntryInfoW')
@winfunctype('WININET.dll')
def FindFirstUrlCacheGroup(dwFlags: UInt32, dwFilter: UInt32, lpSearchCondition: VoidPtr, dwSearchCondition: UInt32, lpGroupId: POINTER(Int64), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('WININET.dll')
def FindNextUrlCacheGroup(hFind: win32more.Windows.Win32.Foundation.HANDLE, lpGroupId: POINTER(Int64), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheGroupAttributeA(gid: Int64, dwFlags: UInt32, dwAttributes: UInt32, lpGroupInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_GROUP_INFOA), lpcbGroupInfo: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheGroupAttributeW(gid: Int64, dwFlags: UInt32, dwAttributes: UInt32, lpGroupInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_GROUP_INFOW), lpcbGroupInfo: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetUrlCacheGroupAttribute = UnicodeAlias('GetUrlCacheGroupAttributeW')
@winfunctype('WININET.dll')
def SetUrlCacheGroupAttributeA(gid: Int64, dwFlags: UInt32, dwAttributes: UInt32, lpGroupInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_GROUP_INFOA), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def SetUrlCacheGroupAttributeW(gid: Int64, dwFlags: UInt32, dwAttributes: UInt32, lpGroupInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_GROUP_INFOW), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetUrlCacheGroupAttribute = UnicodeAlias('SetUrlCacheGroupAttributeW')
@winfunctype('WININET.dll')
def GetUrlCacheEntryInfoExA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32), lpszRedirectUrl: win32more.Windows.Win32.Foundation.PSTR, lpcbRedirectUrl: POINTER(UInt32), lpReserved: VoidPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheEntryInfoExW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32), lpszRedirectUrl: win32more.Windows.Win32.Foundation.PWSTR, lpcbRedirectUrl: POINTER(UInt32), lpReserved: VoidPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetUrlCacheEntryInfoEx = UnicodeAlias('GetUrlCacheEntryInfoExW')
@winfunctype('WININET.dll')
def SetUrlCacheEntryInfoA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), dwFieldControl: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def SetUrlCacheEntryInfoW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, lpCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), dwFieldControl: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetUrlCacheEntryInfo = UnicodeAlias('SetUrlCacheEntryInfoW')
@winfunctype('WININET.dll')
def CreateUrlCacheGroup(dwFlags: UInt32, lpReserved: VoidPtr) -> Int64: ...
@winfunctype('WININET.dll')
def DeleteUrlCacheGroup(GroupId: Int64, dwFlags: UInt32, lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def SetUrlCacheEntryGroupA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, GroupId: Int64, pbGroupAttributes: POINTER(Byte), cbGroupAttributes: UInt32, lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def SetUrlCacheEntryGroupW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, GroupId: Int64, pbGroupAttributes: POINTER(Byte), cbGroupAttributes: UInt32, lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetUrlCacheEntryGroup = UnicodeAlias('SetUrlCacheEntryGroupW')
@winfunctype('WININET.dll')
def FindFirstUrlCacheEntryExA(lpszUrlSearchPattern: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, dwFilter: UInt32, GroupId: Int64, lpFirstCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32), lpGroupAttributes: VoidPtr, lpcbGroupAttributes: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('WININET.dll')
def FindFirstUrlCacheEntryExW(lpszUrlSearchPattern: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, dwFilter: UInt32, GroupId: Int64, lpFirstCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32), lpGroupAttributes: VoidPtr, lpcbGroupAttributes: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.HANDLE: ...
FindFirstUrlCacheEntryEx = UnicodeAlias('FindFirstUrlCacheEntryExW')
@winfunctype('WININET.dll')
def FindNextUrlCacheEntryExA(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE, lpNextCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32), lpGroupAttributes: VoidPtr, lpcbGroupAttributes: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FindNextUrlCacheEntryExW(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE, lpNextCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32), lpGroupAttributes: VoidPtr, lpcbGroupAttributes: POINTER(UInt32), lpReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
FindNextUrlCacheEntryEx = UnicodeAlias('FindNextUrlCacheEntryExW')
@winfunctype('WININET.dll')
def FindFirstUrlCacheEntryA(lpszUrlSearchPattern: win32more.Windows.Win32.Foundation.PSTR, lpFirstCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('WININET.dll')
def FindFirstUrlCacheEntryW(lpszUrlSearchPattern: win32more.Windows.Win32.Foundation.PWSTR, lpFirstCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
FindFirstUrlCacheEntry = UnicodeAlias('FindFirstUrlCacheEntryW')
@winfunctype('WININET.dll')
def FindNextUrlCacheEntryA(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE, lpNextCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), lpcbCacheEntryInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FindNextUrlCacheEntryW(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE, lpNextCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOW), lpcbCacheEntryInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
FindNextUrlCacheEntry = UnicodeAlias('FindNextUrlCacheEntryW')
@winfunctype('WININET.dll')
def FindCloseUrlCache(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def DeleteUrlCacheEntryA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def DeleteUrlCacheEntryW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeleteUrlCacheEntry = UnicodeAlias('DeleteUrlCacheEntryW')
@winfunctype('WININET.dll')
def InternetDialA(hwndParent: win32more.Windows.Win32.Foundation.HWND, lpszConnectoid: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, lpdwConnection: POINTER(UIntPtr), dwReserved: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetDialW(hwndParent: win32more.Windows.Win32.Foundation.HWND, lpszConnectoid: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, lpdwConnection: POINTER(UIntPtr), dwReserved: UInt32) -> UInt32: ...
InternetDial = UnicodeAlias('InternetDialW')
@winfunctype('WININET.dll')
def InternetHangUp(dwConnection: UIntPtr, dwReserved: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetGoOnlineA(lpszURL: win32more.Windows.Win32.Foundation.PSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGoOnlineW(lpszURL: win32more.Windows.Win32.Foundation.PWSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetGoOnline = UnicodeAlias('InternetGoOnlineW')
@winfunctype('WININET.dll')
def InternetAutodial(dwFlags: win32more.Windows.Win32.Networking.WinInet.INTERNET_AUTODIAL, hwndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetAutodialHangup(dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetConnectedState(lpdwFlags: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetConnectedStateExA(lpdwFlags: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION), lpszConnectionName: win32more.Windows.Win32.Foundation.PSTR, cchNameLen: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetConnectedStateExW(lpdwFlags: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION), lpszConnectionName: win32more.Windows.Win32.Foundation.PWSTR, cchNameLen: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetGetConnectedStateEx = UnicodeAlias('InternetGetConnectedStateExW')
@winfunctype('WININET.dll')
def DeleteWpadCacheForNetworks(param0: win32more.Windows.Win32.Networking.WinInet.WPAD_CACHE_DELETE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetInitializeAutoProxyDll(dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def DetectAutoProxyUrl(pszAutoProxyUrl: win32more.Windows.Win32.Foundation.PSTR, cchAutoProxyUrl: UInt32, dwDetectFlags: win32more.Windows.Win32.Networking.WinInet.PROXY_AUTO_DETECT_TYPE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def CreateMD5SSOHash(pszChallengeInfo: win32more.Windows.Win32.Foundation.PWSTR, pwszRealm: win32more.Windows.Win32.Foundation.PWSTR, pwszTarget: win32more.Windows.Win32.Foundation.PWSTR, pbHexHash: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetSetDialStateA(lpszConnectoid: win32more.Windows.Win32.Foundation.PSTR, dwState: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetSetDialStateW(lpszConnectoid: win32more.Windows.Win32.Foundation.PWSTR, dwState: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetSetDialState = UnicodeAlias('InternetSetDialStateW')
@winfunctype('WININET.dll')
def InternetSetPerSiteCookieDecisionA(pchHostName: win32more.Windows.Win32.Foundation.PSTR, dwDecision: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetSetPerSiteCookieDecisionW(pchHostName: win32more.Windows.Win32.Foundation.PWSTR, dwDecision: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetSetPerSiteCookieDecision = UnicodeAlias('InternetSetPerSiteCookieDecisionW')
@winfunctype('WININET.dll')
def InternetGetPerSiteCookieDecisionA(pchHostName: win32more.Windows.Win32.Foundation.PSTR, pResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetPerSiteCookieDecisionW(pchHostName: win32more.Windows.Win32.Foundation.PWSTR, pResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetGetPerSiteCookieDecision = UnicodeAlias('InternetGetPerSiteCookieDecisionW')
@winfunctype('WININET.dll')
def InternetClearAllPerSiteCookieDecisions() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetEnumPerSiteCookieDecisionA(pszSiteName: win32more.Windows.Win32.Foundation.PSTR, pcSiteNameSize: POINTER(UInt32), pdwDecision: POINTER(UInt32), dwIndex: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetEnumPerSiteCookieDecisionW(pszSiteName: win32more.Windows.Win32.Foundation.PWSTR, pcSiteNameSize: POINTER(UInt32), pdwDecision: POINTER(UInt32), dwIndex: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetEnumPerSiteCookieDecision = UnicodeAlias('InternetEnumPerSiteCookieDecisionW')
@winfunctype('WININET.dll')
def PrivacySetZonePreferenceW(dwZone: UInt32, dwType: UInt32, dwTemplate: UInt32, pszPreference: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('WININET.dll')
def PrivacyGetZonePreferenceW(dwZone: UInt32, dwType: UInt32, pdwTemplate: POINTER(UInt32), pszBuffer: win32more.Windows.Win32.Foundation.PWSTR, pdwBufferLength: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def HttpIsHostHstsEnabled(pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pfIsHsts: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetAlgIdToStringA(ai: win32more.Windows.Win32.Security.Cryptography.ALG_ID, lpstr: win32more.Windows.Win32.Foundation.PSTR, lpdwstrLength: POINTER(UInt32), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetAlgIdToStringW(ai: win32more.Windows.Win32.Security.Cryptography.ALG_ID, lpstr: win32more.Windows.Win32.Foundation.PWSTR, lpdwstrLength: POINTER(UInt32), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetAlgIdToString = UnicodeAlias('InternetAlgIdToStringW')
@winfunctype('WININET.dll')
def InternetSecurityProtocolToStringA(dwProtocol: UInt32, lpstr: win32more.Windows.Win32.Foundation.PSTR, lpdwstrLength: POINTER(UInt32), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetSecurityProtocolToStringW(dwProtocol: UInt32, lpstr: win32more.Windows.Win32.Foundation.PWSTR, lpdwstrLength: POINTER(UInt32), dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetSecurityProtocolToString = UnicodeAlias('InternetSecurityProtocolToStringW')
@winfunctype('WININET.dll')
def InternetGetSecurityInfoByURLA(lpszURL: win32more.Windows.Win32.Foundation.PSTR, ppCertChain: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CHAIN_CONTEXT)), pdwSecureFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetGetSecurityInfoByURLW(lpszURL: win32more.Windows.Win32.Foundation.PWSTR, ppCertChain: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CHAIN_CONTEXT)), pdwSecureFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetGetSecurityInfoByURL = UnicodeAlias('InternetGetSecurityInfoByURLW')
@winfunctype('WININET.dll')
def ShowSecurityInfo(hWndParent: win32more.Windows.Win32.Foundation.HWND, pSecurityInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_SECURITY_INFO)) -> UInt32: ...
@winfunctype('WININET.dll')
def ShowX509EncodedCertificate(hWndParent: win32more.Windows.Win32.Foundation.HWND, lpCert: POINTER(Byte), cbCert: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def ShowClientAuthCerts(hWndParent: win32more.Windows.Win32.Foundation.HWND) -> UInt32: ...
@winfunctype('WININET.dll')
def ParseX509EncodedCertificateForListBoxEntry(lpCert: POINTER(Byte), cbCert: UInt32, lpszListBoxEntry: win32more.Windows.Win32.Foundation.PSTR, lpdwListBoxEntry: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def InternetShowSecurityInfoByURLA(lpszURL: win32more.Windows.Win32.Foundation.PSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetShowSecurityInfoByURLW(lpszURL: win32more.Windows.Win32.Foundation.PWSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetShowSecurityInfoByURL = UnicodeAlias('InternetShowSecurityInfoByURLW')
@winfunctype('WININET.dll')
def InternetFortezzaCommand(dwCommand: UInt32, hwnd: win32more.Windows.Win32.Foundation.HWND, dwReserved: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetQueryFortezzaStatus(pdwStatus: POINTER(UInt32), dwReserved: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetWriteFileExA(hFile: VoidPtr, lpBuffersIn: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSA), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetWriteFileExW(hFile: VoidPtr, lpBuffersIn: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSW), dwFlags: UInt32, dwContext: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
InternetWriteFileEx = UnicodeAlias('InternetWriteFileExW')
@winfunctype('WININET.dll')
def FindP3PPolicySymbol(pszSymbol: win32more.Windows.Win32.Foundation.PSTR) -> Int32: ...
@winfunctype('WININET.dll')
def HttpGetServerCredentials(pwszUrl: win32more.Windows.Win32.Foundation.PWSTR, ppwszUserName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppwszPassword: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('WININET.dll')
def HttpPushEnable(hRequest: VoidPtr, pTransportSetting: POINTER(win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_TRANSPORT_SETTING), phWait: POINTER(win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_WAIT_HANDLE)) -> UInt32: ...
@winfunctype('WININET.dll')
def HttpPushWait(hWait: win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_WAIT_HANDLE, eType: win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_WAIT_TYPE, pNotificationStatus: POINTER(win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_NOTIFICATION_STATUS)) -> UInt32: ...
@winfunctype('WININET.dll')
def HttpPushClose(hWait: win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_WAIT_HANDLE) -> Void: ...
@winfunctype('WININET.dll')
def HttpCheckDavComplianceA(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszComplianceToken: win32more.Windows.Win32.Foundation.PSTR, lpfFound: POINTER(win32more.Windows.Win32.Foundation.BOOL), hWnd: win32more.Windows.Win32.Foundation.HWND, lpvReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpCheckDavComplianceW(lpszUrl: win32more.Windows.Win32.Foundation.PWSTR, lpszComplianceToken: win32more.Windows.Win32.Foundation.PWSTR, lpfFound: POINTER(win32more.Windows.Win32.Foundation.BOOL), hWnd: win32more.Windows.Win32.Foundation.HWND, lpvReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
HttpCheckDavCompliance = UnicodeAlias('HttpCheckDavComplianceW')
@winfunctype('WININET.dll')
def IsUrlCacheEntryExpiredA(lpszUrlName: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, pftLastModified: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def IsUrlCacheEntryExpiredW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, pftLastModified: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsUrlCacheEntryExpired = UnicodeAlias('IsUrlCacheEntryExpiredW')
@winfunctype('WININET.dll')
def CreateUrlCacheEntryExW(lpszUrlName: win32more.Windows.Win32.Foundation.PWSTR, dwExpectedFileSize: UInt32, lpszFileExtension: win32more.Windows.Win32.Foundation.PWSTR, lpszFileName: win32more.Windows.Win32.Foundation.PWSTR, dwReserved: UInt32, fPreserveIncomingFileName: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheEntryBinaryBlob(pwszUrlName: win32more.Windows.Win32.Foundation.PWSTR, dwType: POINTER(UInt32), pftExpireTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), pftAccessTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), pftModifiedTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), ppbBlob: POINTER(POINTER(Byte)), pcbBlob: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def CommitUrlCacheEntryBinaryBlob(pwszUrlName: win32more.Windows.Win32.Foundation.PWSTR, dwType: UInt32, ftExpireTime: win32more.Windows.Win32.Foundation.FILETIME, ftModifiedTime: win32more.Windows.Win32.Foundation.FILETIME, pbBlob: POINTER(Byte), cbBlob: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def CreateUrlCacheContainerA(Name: win32more.Windows.Win32.Foundation.PSTR, lpCachePrefix: win32more.Windows.Win32.Foundation.PSTR, lpszCachePath: win32more.Windows.Win32.Foundation.PSTR, KBCacheLimit: UInt32, dwContainerType: UInt32, dwOptions: UInt32, pvBuffer: VoidPtr, cbBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def CreateUrlCacheContainerW(Name: win32more.Windows.Win32.Foundation.PWSTR, lpCachePrefix: win32more.Windows.Win32.Foundation.PWSTR, lpszCachePath: win32more.Windows.Win32.Foundation.PWSTR, KBCacheLimit: UInt32, dwContainerType: UInt32, dwOptions: UInt32, pvBuffer: VoidPtr, cbBuffer: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
CreateUrlCacheContainer = UnicodeAlias('CreateUrlCacheContainerW')
@winfunctype('WININET.dll')
def DeleteUrlCacheContainerA(Name: win32more.Windows.Win32.Foundation.PSTR, dwOptions: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def DeleteUrlCacheContainerW(Name: win32more.Windows.Win32.Foundation.PWSTR, dwOptions: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
DeleteUrlCacheContainer = UnicodeAlias('DeleteUrlCacheContainerW')
@winfunctype('WININET.dll')
def FindFirstUrlCacheContainerA(pdwModified: POINTER(UInt32), lpContainerInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONTAINER_INFOA), lpcbContainerInfo: POINTER(UInt32), dwOptions: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('WININET.dll')
def FindFirstUrlCacheContainerW(pdwModified: POINTER(UInt32), lpContainerInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONTAINER_INFOW), lpcbContainerInfo: POINTER(UInt32), dwOptions: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
FindFirstUrlCacheContainer = UnicodeAlias('FindFirstUrlCacheContainerW')
@winfunctype('WININET.dll')
def FindNextUrlCacheContainerA(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE, lpContainerInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONTAINER_INFOA), lpcbContainerInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FindNextUrlCacheContainerW(hEnumHandle: win32more.Windows.Win32.Foundation.HANDLE, lpContainerInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONTAINER_INFOW), lpcbContainerInfo: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
FindNextUrlCacheContainer = UnicodeAlias('FindNextUrlCacheContainerW')
@winfunctype('WININET.dll')
def FreeUrlCacheSpaceA(lpszCachePath: win32more.Windows.Win32.Foundation.PSTR, dwSize: UInt32, dwFilter: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def FreeUrlCacheSpaceW(lpszCachePath: win32more.Windows.Win32.Foundation.PWSTR, dwSize: UInt32, dwFilter: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
FreeUrlCacheSpace = UnicodeAlias('FreeUrlCacheSpaceW')
@winfunctype('WININET.dll')
def UrlCacheFreeGlobalSpace(ullTargetSize: UInt64, dwFilter: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheGetGlobalCacheSize(dwFilter: UInt32, pullSize: POINTER(UInt64), pullLimit: POINTER(UInt64)) -> UInt32: ...
@winfunctype('WININET.dll')
def GetUrlCacheConfigInfoA(lpCacheConfigInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONFIG_INFOA), lpcbCacheConfigInfo: POINTER(UInt32), dwFieldControl: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheConfigInfoW(lpCacheConfigInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONFIG_INFOW), lpcbCacheConfigInfo: POINTER(UInt32), dwFieldControl: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetUrlCacheConfigInfo = UnicodeAlias('GetUrlCacheConfigInfoW')
@winfunctype('WININET.dll')
def SetUrlCacheConfigInfoA(lpCacheConfigInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONFIG_INFOA), dwFieldControl: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def SetUrlCacheConfigInfoW(lpCacheConfigInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONFIG_INFOW), dwFieldControl: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetUrlCacheConfigInfo = UnicodeAlias('SetUrlCacheConfigInfoW')
@winfunctype('WININET.dll')
def RunOnceUrlCache(hwnd: win32more.Windows.Win32.Foundation.HWND, hinst: win32more.Windows.Win32.Foundation.HINSTANCE, lpszCmd: win32more.Windows.Win32.Foundation.PSTR, nCmdShow: Int32) -> UInt32: ...
@winfunctype('WININET.dll')
def DeleteIE3Cache(hwnd: win32more.Windows.Win32.Foundation.HWND, hinst: win32more.Windows.Win32.Foundation.HINSTANCE, lpszCmd: win32more.Windows.Win32.Foundation.PSTR, nCmdShow: Int32) -> UInt32: ...
@winfunctype('WININET.dll')
def UpdateUrlCacheContentPath(szNewPath: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def RegisterUrlCacheNotification(hWnd: win32more.Windows.Win32.Foundation.HWND, uMsg: UInt32, gid: Int64, dwOpsFilter: UInt32, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetUrlCacheHeaderData(nIdx: UInt32, lpdwData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def SetUrlCacheHeaderData(nIdx: UInt32, dwData: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def IncrementUrlCacheHeaderData(nIdx: UInt32, lpdwData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def LoadUrlCacheContent() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def AppCacheLookup(pwszUrl: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, phAppCache: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheCheckManifest(pwszMasterUrl: win32more.Windows.Win32.Foundation.PWSTR, pwszManifestUrl: win32more.Windows.Win32.Foundation.PWSTR, pbManifestData: POINTER(Byte), dwManifestDataSize: UInt32, pbManifestResponseHeaders: POINTER(Byte), dwManifestResponseHeadersSize: UInt32, peState: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_STATE), phNewAppCache: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheGetDownloadList(hAppCache: VoidPtr, pDownloadList: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_DOWNLOAD_LIST)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheFreeDownloadList(pDownloadList: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_DOWNLOAD_LIST)) -> Void: ...
@winfunctype('WININET.dll')
def AppCacheFinalize(hAppCache: VoidPtr, pbManifestData: POINTER(Byte), dwManifestDataSize: UInt32, peState: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_FINALIZE_STATE)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheGetFallbackUrl(hAppCache: VoidPtr, pwszUrl: win32more.Windows.Win32.Foundation.PWSTR, ppwszFallbackUrl: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheGetManifestUrl(hAppCache: VoidPtr, ppwszManifestUrl: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheDuplicateHandle(hAppCache: VoidPtr, phDuplicatedAppCache: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheCloseHandle(hAppCache: VoidPtr) -> Void: ...
@winfunctype('WININET.dll')
def AppCacheFreeGroupList(pAppCacheGroupList: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_GROUP_LIST)) -> Void: ...
@winfunctype('WININET.dll')
def AppCacheGetGroupList(pAppCacheGroupList: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_GROUP_LIST)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheGetInfo(hAppCache: VoidPtr, pAppCacheInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_GROUP_INFO)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheDeleteGroup(pwszManifestUrl: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheFreeSpace(ftCutOff: win32more.Windows.Win32.Foundation.FILETIME) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheGetIEGroupList(pAppCacheGroupList: POINTER(win32more.Windows.Win32.Networking.WinInet.APP_CACHE_GROUP_LIST)) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheDeleteIEGroup(pwszManifestUrl: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheFreeIESpace(ftCutOff: win32more.Windows.Win32.Foundation.FILETIME) -> UInt32: ...
@winfunctype('WININET.dll')
def AppCacheCreateAndCommitFile(hAppCache: VoidPtr, pwszSourceFilePath: win32more.Windows.Win32.Foundation.PWSTR, pwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pbResponseHeaders: POINTER(Byte), dwResponseHeadersSize: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def HttpOpenDependencyHandle(hRequestHandle: VoidPtr, fBackground: win32more.Windows.Win32.Foundation.BOOL, phDependencyHandle: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def HttpCloseDependencyHandle(hDependencyHandle: VoidPtr) -> Void: ...
@winfunctype('WININET.dll')
def HttpDuplicateDependencyHandle(hDependencyHandle: VoidPtr, phDuplicatedDependencyHandle: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def HttpIndicatePageLoadComplete(hDependencyHandle: VoidPtr) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheFreeEntryInfo(pCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.URLCACHE_ENTRY_INFO)) -> Void: ...
@winfunctype('WININET.dll')
def UrlCacheGetEntryInfo(hAppCache: VoidPtr, pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.URLCACHE_ENTRY_INFO)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheCloseEntryHandle(hEntryFile: VoidPtr) -> Void: ...
@winfunctype('WININET.dll')
def UrlCacheRetrieveEntryFile(hAppCache: VoidPtr, pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.URLCACHE_ENTRY_INFO), phEntryFile: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheReadEntryStream(hUrlCacheStream: VoidPtr, ullLocation: UInt64, pBuffer: VoidPtr, dwBufferLen: UInt32, pdwBufferLen: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheRetrieveEntryStream(hAppCache: VoidPtr, pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, fRandomRead: win32more.Windows.Win32.Foundation.BOOL, pCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.URLCACHE_ENTRY_INFO), phEntryStream: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheUpdateEntryExtraData(hAppCache: VoidPtr, pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pbExtraData: POINTER(Byte), cbExtraData: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheCreateContainer(pwszName: win32more.Windows.Win32.Foundation.PWSTR, pwszPrefix: win32more.Windows.Win32.Foundation.PWSTR, pwszDirectory: win32more.Windows.Win32.Foundation.PWSTR, ullLimit: UInt64, dwOptions: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheCheckEntriesExist(rgpwszUrls: POINTER(win32more.Windows.Win32.Foundation.PWSTR), cEntries: UInt32, rgfExist: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheGetContentPaths(pppwszDirectories: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), pcDirectories: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheGetGlobalLimit(limitType: win32more.Windows.Win32.Networking.WinInet.URL_CACHE_LIMIT_TYPE, pullLimit: POINTER(UInt64)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheSetGlobalLimit(limitType: win32more.Windows.Win32.Networking.WinInet.URL_CACHE_LIMIT_TYPE, ullLimit: UInt64) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheReloadSettings() -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheContainerSetEntryMaximumAge(pwszPrefix: win32more.Windows.Win32.Foundation.PWSTR, dwEntryMaxAge: UInt32) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheFindFirstEntry(pwszPrefix: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, dwFilter: UInt32, GroupId: Int64, pCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.URLCACHE_ENTRY_INFO), phFind: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheFindNextEntry(hFind: win32more.Windows.Win32.Foundation.HANDLE, pCacheEntryInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.URLCACHE_ENTRY_INFO)) -> UInt32: ...
@winfunctype('WININET.dll')
def UrlCacheServer() -> UInt32: ...
@winfunctype('WININET.dll')
def ReadGuidsForConnectedNetworks(pcNetworks: POINTER(UInt32), pppwszNetworkGuids: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), pppbstrNetworkNames: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR)), pppwszGWMacs: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), pcGatewayMacs: POINTER(UInt32), pdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def IsHostInProxyBypassList(tScheme: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME, lpszHost: win32more.Windows.Win32.Foundation.PSTR, cchHost: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetFreeProxyInfoList(pProxyInfoList: POINTER(win32more.Windows.Win32.Networking.WinInet.WININET_PROXY_INFO_LIST)) -> Void: ...
@winfunctype('WININET.dll')
def InternetGetProxyForUrl(hInternet: VoidPtr, pcwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pProxyInfoList: POINTER(win32more.Windows.Win32.Networking.WinInet.WININET_PROXY_INFO_LIST)) -> UInt32: ...
@winfunctype('WININET.dll')
def DoConnectoidsExist() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def GetDiskInfoA(pszPath: win32more.Windows.Win32.Foundation.PSTR, pdwClusterSize: POINTER(UInt32), pdlAvail: POINTER(UInt64), pdlTotal: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def PerformOperationOverUrlCacheA(pszUrlSearchPattern: win32more.Windows.Win32.Foundation.PSTR, dwFlags: UInt32, dwFilter: UInt32, GroupId: Int64, pReserved1: VoidPtr, pdwReserved2: POINTER(UInt32), pReserved3: VoidPtr, op: win32more.Windows.Win32.Networking.WinInet.CACHE_OPERATOR, pOperatorData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def IsProfilesEnabled() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternalInternetGetCookie(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, lpszCookieData: win32more.Windows.Win32.Foundation.PSTR, lpdwDataSize: POINTER(UInt32)) -> UInt32: ...
@winfunctype('WININET.dll')
def ImportCookieFileA(szFilename: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def ImportCookieFileW(szFilename: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
ImportCookieFile = UnicodeAlias('ImportCookieFileW')
@winfunctype('WININET.dll')
def ExportCookieFileA(szFilename: win32more.Windows.Win32.Foundation.PSTR, fAppend: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def ExportCookieFileW(szFilename: win32more.Windows.Win32.Foundation.PWSTR, fAppend: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
ExportCookieFile = UnicodeAlias('ExportCookieFileW')
@winfunctype('WININET.dll')
def IsDomainLegalCookieDomainA(pchDomain: win32more.Windows.Win32.Foundation.PSTR, pchFullDomain: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def IsDomainLegalCookieDomainW(pchDomain: win32more.Windows.Win32.Foundation.PWSTR, pchFullDomain: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsDomainLegalCookieDomain = UnicodeAlias('IsDomainLegalCookieDomainW')
@winfunctype('WININET.dll')
def HttpWebSocketCompleteUpgrade(hRequest: VoidPtr, dwContext: UIntPtr) -> VoidPtr: ...
@winfunctype('WININET.dll')
def HttpWebSocketSend(hWebSocket: VoidPtr, BufferType: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE, pvBuffer: VoidPtr, dwBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpWebSocketReceive(hWebSocket: VoidPtr, pvBuffer: VoidPtr, dwBufferLength: UInt32, pdwBytesRead: POINTER(UInt32), pBufferType: POINTER(win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpWebSocketClose(hWebSocket: VoidPtr, usStatus: UInt16, pvReason: VoidPtr, dwReasonLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpWebSocketShutdown(hWebSocket: VoidPtr, usStatus: UInt16, pvReason: VoidPtr, dwReasonLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def HttpWebSocketQueryCloseStatus(hWebSocket: VoidPtr, pusStatus: POINTER(UInt16), pvReason: VoidPtr, dwReasonLength: UInt32, pdwReasonLengthConsumed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WININET.dll')
def InternetConvertUrlFromWireToWideChar(pcszUrl: win32more.Windows.Win32.Foundation.PSTR, cchUrl: UInt32, pcwszBaseUrl: win32more.Windows.Win32.Foundation.PWSTR, dwCodePageHost: UInt32, dwCodePagePath: UInt32, fEncodePathExtra: win32more.Windows.Win32.Foundation.BOOL, dwCodePageExtra: UInt32, ppwszConvertedUrl: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> UInt32: ...
class AutoProxyHelperFunctions(Structure):
    lpVtbl: POINTER(win32more.Windows.Win32.Networking.WinInet.AutoProxyHelperVtbl)
class AutoProxyHelperVtbl(Structure):
    IsResolvable: IntPtr
    GetIPAddress: IntPtr
    ResolveHostName: IntPtr
    IsInNet: IntPtr
    IsResolvableEx: IntPtr
    GetIPAddressEx: IntPtr
    ResolveHostNameEx: IntPtr
    IsInNetEx: IntPtr
    SortIpList: IntPtr
CACHE_CONFIG = UInt32
CACHE_CONFIG_FORCE_CLEANUP_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 32
CACHE_CONFIG_DISK_CACHE_PATHS_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 64
CACHE_CONFIG_SYNC_MODE_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 128
CACHE_CONFIG_CONTENT_PATHS_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 256
CACHE_CONFIG_HISTORY_PATHS_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 1024
CACHE_CONFIG_COOKIES_PATHS_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 512
CACHE_CONFIG_QUOTA_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 2048
CACHE_CONFIG_USER_MODE_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 4096
CACHE_CONFIG_CONTENT_USAGE_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 8192
CACHE_CONFIG_STICKY_CONTENT_USAGE_FC: win32more.Windows.Win32.Networking.WinInet.CACHE_CONFIG = 16384
@winfunctype_pointer
def CACHE_OPERATOR(pcei: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_ENTRY_INFOA), pcbcei: POINTER(UInt32), pOpData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
class COOKIE_DLG_INFO(Structure):
    pszServer: win32more.Windows.Win32.Foundation.PWSTR
    pic: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE)
    dwStopWarning: UInt32
    cx: Int32
    cy: Int32
    pszHeader: win32more.Windows.Win32.Foundation.PWSTR
    dwOperation: UInt32
class CookieDecision(Structure):
    dwCookieState: UInt32
    fAllowSession: win32more.Windows.Win32.Foundation.BOOL
FORTCMD = Int32
FORTCMD_LOGON: win32more.Windows.Win32.Networking.WinInet.FORTCMD = 1
FORTCMD_LOGOFF: win32more.Windows.Win32.Networking.WinInet.FORTCMD = 2
FORTCMD_CHG_PERSONALITY: win32more.Windows.Win32.Networking.WinInet.FORTCMD = 3
FORTSTAT = Int32
FORTSTAT_INSTALLED: win32more.Windows.Win32.Networking.WinInet.FORTSTAT = 1
FORTSTAT_LOGGEDON: win32more.Windows.Win32.Networking.WinInet.FORTSTAT = 2
FTP_FLAGS = UInt32
FTP_TRANSFER_TYPE_ASCII: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS = 1
FTP_TRANSFER_TYPE_BINARY: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS = 2
FTP_TRANSFER_TYPE_UNKNOWN: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS = 0
INTERNET_FLAG_TRANSFER_ASCII: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS = 1
INTERNET_FLAG_TRANSFER_BINARY: win32more.Windows.Win32.Networking.WinInet.FTP_FLAGS = 2
class GOPHER_ABSTRACT_ATTRIBUTE_TYPE(Structure):
    ShortAbstract: POINTER(SByte)
    AbstractFile: POINTER(SByte)
class GOPHER_ADMIN_ATTRIBUTE_TYPE(Structure):
    Comment: POINTER(SByte)
    EmailAddress: POINTER(SByte)
class GOPHER_ASK_ATTRIBUTE_TYPE(Structure):
    QuestionType: POINTER(SByte)
    QuestionText: POINTER(SByte)
@winfunctype_pointer
def GOPHER_ATTRIBUTE_ENUMERATOR(lpAttributeInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.GOPHER_ATTRIBUTE_TYPE), dwError: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
class GOPHER_ATTRIBUTE_TYPE(Structure):
    CategoryId: UInt32
    AttributeId: UInt32
    AttributeType: _AttributeType_e__Union
    class _AttributeType_e__Union(Union):
        Admin: win32more.Windows.Win32.Networking.WinInet.GOPHER_ADMIN_ATTRIBUTE_TYPE
        ModDate: win32more.Windows.Win32.Networking.WinInet.GOPHER_MOD_DATE_ATTRIBUTE_TYPE
        Ttl: win32more.Windows.Win32.Networking.WinInet.GOPHER_TTL_ATTRIBUTE_TYPE
        Score: win32more.Windows.Win32.Networking.WinInet.GOPHER_SCORE_ATTRIBUTE_TYPE
        ScoreRange: win32more.Windows.Win32.Networking.WinInet.GOPHER_SCORE_RANGE_ATTRIBUTE_TYPE
        Site: win32more.Windows.Win32.Networking.WinInet.GOPHER_SITE_ATTRIBUTE_TYPE
        Organization: win32more.Windows.Win32.Networking.WinInet.GOPHER_ORGANIZATION_ATTRIBUTE_TYPE
        Location: win32more.Windows.Win32.Networking.WinInet.GOPHER_LOCATION_ATTRIBUTE_TYPE
        GeographicalLocation: win32more.Windows.Win32.Networking.WinInet.GOPHER_GEOGRAPHICAL_LOCATION_ATTRIBUTE_TYPE
        TimeZone: win32more.Windows.Win32.Networking.WinInet.GOPHER_TIMEZONE_ATTRIBUTE_TYPE
        Provider: win32more.Windows.Win32.Networking.WinInet.GOPHER_PROVIDER_ATTRIBUTE_TYPE
        Version: win32more.Windows.Win32.Networking.WinInet.GOPHER_VERSION_ATTRIBUTE_TYPE
        Abstract: win32more.Windows.Win32.Networking.WinInet.GOPHER_ABSTRACT_ATTRIBUTE_TYPE
        View: win32more.Windows.Win32.Networking.WinInet.GOPHER_VIEW_ATTRIBUTE_TYPE
        Veronica: win32more.Windows.Win32.Networking.WinInet.GOPHER_VERONICA_ATTRIBUTE_TYPE
        Ask: win32more.Windows.Win32.Networking.WinInet.GOPHER_ASK_ATTRIBUTE_TYPE
        Unknown: win32more.Windows.Win32.Networking.WinInet.GOPHER_UNKNOWN_ATTRIBUTE_TYPE
class GOPHER_FIND_DATAA(Structure):
    DisplayString: win32more.Windows.Win32.Foundation.CHAR * 129
    GopherType: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE
    SizeLow: UInt32
    SizeHigh: UInt32
    LastModificationTime: win32more.Windows.Win32.Foundation.FILETIME
    Locator: win32more.Windows.Win32.Foundation.CHAR * 654
class GOPHER_FIND_DATAW(Structure):
    DisplayString: Char * 129
    GopherType: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE
    SizeLow: UInt32
    SizeHigh: UInt32
    LastModificationTime: win32more.Windows.Win32.Foundation.FILETIME
    Locator: Char * 654
GOPHER_FIND_DATA = UnicodeAlias('GOPHER_FIND_DATAW')
class GOPHER_GEOGRAPHICAL_LOCATION_ATTRIBUTE_TYPE(Structure):
    DegreesNorth: Int32
    MinutesNorth: Int32
    SecondsNorth: Int32
    DegreesEast: Int32
    MinutesEast: Int32
    SecondsEast: Int32
class GOPHER_LOCATION_ATTRIBUTE_TYPE(Structure):
    Location: POINTER(SByte)
class GOPHER_MOD_DATE_ATTRIBUTE_TYPE(Structure):
    DateAndTime: win32more.Windows.Win32.Foundation.FILETIME
class GOPHER_ORGANIZATION_ATTRIBUTE_TYPE(Structure):
    Organization: POINTER(SByte)
class GOPHER_PROVIDER_ATTRIBUTE_TYPE(Structure):
    Provider: POINTER(SByte)
class GOPHER_SCORE_ATTRIBUTE_TYPE(Structure):
    Score: Int32
class GOPHER_SCORE_RANGE_ATTRIBUTE_TYPE(Structure):
    LowerBound: Int32
    UpperBound: Int32
class GOPHER_SITE_ATTRIBUTE_TYPE(Structure):
    Site: POINTER(SByte)
class GOPHER_TIMEZONE_ATTRIBUTE_TYPE(Structure):
    Zone: Int32
class GOPHER_TTL_ATTRIBUTE_TYPE(Structure):
    Ttl: UInt32
GOPHER_TYPE = UInt32
GOPHER_TYPE_ASK: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 1073741824
GOPHER_TYPE_BINARY: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 512
GOPHER_TYPE_BITMAP: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 16384
GOPHER_TYPE_CALENDAR: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 524288
GOPHER_TYPE_CSO: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 4
GOPHER_TYPE_DIRECTORY: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 2
GOPHER_TYPE_DOS_ARCHIVE: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 32
GOPHER_TYPE_ERROR: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 8
GOPHER_TYPE_GIF: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 4096
GOPHER_TYPE_GOPHER_PLUS: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 2147483648
GOPHER_TYPE_HTML: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 131072
GOPHER_TYPE_IMAGE: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 8192
GOPHER_TYPE_INDEX_SERVER: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 128
GOPHER_TYPE_INLINE: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 1048576
GOPHER_TYPE_MAC_BINHEX: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 16
GOPHER_TYPE_MOVIE: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 32768
GOPHER_TYPE_PDF: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 262144
GOPHER_TYPE_REDUNDANT: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 1024
GOPHER_TYPE_SOUND: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 65536
GOPHER_TYPE_TELNET: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 256
GOPHER_TYPE_TEXT_FILE: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 1
GOPHER_TYPE_TN3270: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 2048
GOPHER_TYPE_UNIX_UUENCODED: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 64
GOPHER_TYPE_UNKNOWN: win32more.Windows.Win32.Networking.WinInet.GOPHER_TYPE = 536870912
class GOPHER_UNKNOWN_ATTRIBUTE_TYPE(Structure):
    Text: POINTER(SByte)
class GOPHER_VERONICA_ATTRIBUTE_TYPE(Structure):
    TreeWalk: win32more.Windows.Win32.Foundation.BOOL
class GOPHER_VERSION_ATTRIBUTE_TYPE(Structure):
    Version: POINTER(SByte)
class GOPHER_VIEW_ATTRIBUTE_TYPE(Structure):
    ContentType: POINTER(SByte)
    Language: POINTER(SByte)
    Size: UInt32
HTTP_ADDREQ_FLAG = UInt32
HTTP_ADDREQ_FLAG_ADD: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG = 536870912
HTTP_ADDREQ_FLAG_ADD_IF_NEW: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG = 268435456
HTTP_ADDREQ_FLAG_COALESCE: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG = 1073741824
HTTP_ADDREQ_FLAG_COALESCE_WITH_COMMA: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG = 1073741824
HTTP_ADDREQ_FLAG_COALESCE_WITH_SEMICOLON: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG = 16777216
HTTP_ADDREQ_FLAG_REPLACE: win32more.Windows.Win32.Networking.WinInet.HTTP_ADDREQ_FLAG = 2147483648
@winfunctype_pointer
def HTTP_POLICY_EXTENSION_INIT(Version: win32more.Windows.Win32.Networking.WinInet.HTTP_POLICY_EXTENSION_VERSION, Type: win32more.Windows.Win32.Networking.WinInet.HTTP_POLICY_EXTENSION_TYPE, pvData: VoidPtr, cbData: UInt32) -> UInt32: ...
@winfunctype_pointer
def HTTP_POLICY_EXTENSION_SHUTDOWN(Type: win32more.Windows.Win32.Networking.WinInet.HTTP_POLICY_EXTENSION_TYPE) -> UInt32: ...
HTTP_POLICY_EXTENSION_TYPE = Int32
POLICY_EXTENSION_TYPE_NONE: win32more.Windows.Win32.Networking.WinInet.HTTP_POLICY_EXTENSION_TYPE = 0
POLICY_EXTENSION_TYPE_WINHTTP: win32more.Windows.Win32.Networking.WinInet.HTTP_POLICY_EXTENSION_TYPE = 1
POLICY_EXTENSION_TYPE_WININET: win32more.Windows.Win32.Networking.WinInet.HTTP_POLICY_EXTENSION_TYPE = 2
HTTP_POLICY_EXTENSION_VERSION = Int32
POLICY_EXTENSION_VERSION1: win32more.Windows.Win32.Networking.WinInet.HTTP_POLICY_EXTENSION_VERSION = 1
class HTTP_PUSH_NOTIFICATION_STATUS(Structure):
    ChannelStatusValid: win32more.Windows.Win32.Foundation.BOOL
    ChannelStatus: UInt32
class HTTP_PUSH_TRANSPORT_SETTING(Structure):
    TransportSettingId: Guid
    BrokerEventId: Guid
HTTP_PUSH_WAIT_HANDLE = VoidPtr
HTTP_PUSH_WAIT_TYPE = Int32
HttpPushWaitEnableComplete: win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_WAIT_TYPE = 0
HttpPushWaitReceiveComplete: win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_WAIT_TYPE = 1
HttpPushWaitSendComplete: win32more.Windows.Win32.Networking.WinInet.HTTP_PUSH_WAIT_TYPE = 2
class HTTP_REQUEST_TIMES(Structure):
    cTimes: UInt32
    rgTimes: UInt64 * 32
class HTTP_WEB_SOCKET_ASYNC_RESULT(Structure):
    AsyncResult: win32more.Windows.Win32.Networking.WinInet.INTERNET_ASYNC_RESULT
    Operation: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_OPERATION
    BufferType: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE
    dwBytesTransferred: UInt32
HTTP_WEB_SOCKET_BUFFER_TYPE = Int32
HTTP_WEB_SOCKET_BINARY_MESSAGE_TYPE: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE = 0
HTTP_WEB_SOCKET_BINARY_FRAGMENT_TYPE: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE = 1
HTTP_WEB_SOCKET_UTF8_MESSAGE_TYPE: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE = 2
HTTP_WEB_SOCKET_UTF8_FRAGMENT_TYPE: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE = 3
HTTP_WEB_SOCKET_CLOSE_TYPE: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE = 4
HTTP_WEB_SOCKET_PING_TYPE: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_BUFFER_TYPE = 5
HTTP_WEB_SOCKET_CLOSE_STATUS = Int32
HTTP_WEB_SOCKET_SUCCESS_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1000
HTTP_WEB_SOCKET_ENDPOINT_TERMINATED_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1001
HTTP_WEB_SOCKET_PROTOCOL_ERROR_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1002
HTTP_WEB_SOCKET_INVALID_DATA_TYPE_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1003
HTTP_WEB_SOCKET_EMPTY_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1005
HTTP_WEB_SOCKET_ABORTED_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1006
HTTP_WEB_SOCKET_INVALID_PAYLOAD_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1007
HTTP_WEB_SOCKET_POLICY_VIOLATION_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1008
HTTP_WEB_SOCKET_MESSAGE_TOO_BIG_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1009
HTTP_WEB_SOCKET_UNSUPPORTED_EXTENSIONS_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1010
HTTP_WEB_SOCKET_SERVER_ERROR_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1011
HTTP_WEB_SOCKET_SECURE_HANDSHAKE_ERROR_CLOSE_STATUS: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_CLOSE_STATUS = 1015
HTTP_WEB_SOCKET_OPERATION = Int32
HTTP_WEB_SOCKET_SEND_OPERATION: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_OPERATION = 0
HTTP_WEB_SOCKET_RECEIVE_OPERATION: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_OPERATION = 1
HTTP_WEB_SOCKET_CLOSE_OPERATION: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_OPERATION = 2
HTTP_WEB_SOCKET_SHUTDOWN_OPERATION: win32more.Windows.Win32.Networking.WinInet.HTTP_WEB_SOCKET_OPERATION = 3
class IDialBranding(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8aecafa9-4306-43cc-8c5a-765f2979cc16}')
    @commethod(3)
    def Initialize(self, pwzConnectoid: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetBitmap(self, dwIndex: UInt32, phBitmap: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDialEngine(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{39fd782b-7905-40d5-9148-3c9b190423d5}')
    @commethod(3)
    def Initialize(self, pwzConnectoid: win32more.Windows.Win32.Foundation.PWSTR, pIDES: win32more.Windows.Win32.Networking.WinInet.IDialEventSink) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperty(self, pwzProperty: win32more.Windows.Win32.Foundation.PWSTR, pwzValue: win32more.Windows.Win32.Foundation.PWSTR, dwBufSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetProperty(self, pwzProperty: win32more.Windows.Win32.Foundation.PWSTR, pwzValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Dial(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def HangUp(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetConnectedState(self, pdwState: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetConnectHandle(self, pdwHandle: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDialEventSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2d86f4ff-6e2d-4488-b2e9-6934afd41bea}')
    @commethod(3)
    def OnEvent(self, dwEvent: UInt32, dwStatus: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
INTERNET_ACCESS_TYPE = UInt32
INTERNET_OPEN_TYPE_DIRECT: win32more.Windows.Win32.Networking.WinInet.INTERNET_ACCESS_TYPE = 1
INTERNET_OPEN_TYPE_PRECONFIG: win32more.Windows.Win32.Networking.WinInet.INTERNET_ACCESS_TYPE = 0
INTERNET_OPEN_TYPE_PROXY: win32more.Windows.Win32.Networking.WinInet.INTERNET_ACCESS_TYPE = 3
class INTERNET_ASYNC_RESULT(Structure):
    dwResult: UIntPtr
    dwError: UInt32
class INTERNET_AUTH_NOTIFY_DATA(Structure):
    cbStruct: UInt32
    dwOptions: UInt32
    pfnNotify: win32more.Windows.Win32.Networking.WinInet.PFN_AUTH_NOTIFY
    dwContext: UIntPtr
INTERNET_AUTODIAL = UInt32
INTERNET_AUTODIAL_FAILIFSECURITYCHECK: win32more.Windows.Win32.Networking.WinInet.INTERNET_AUTODIAL = 4
INTERNET_AUTODIAL_FORCE_ONLINE: win32more.Windows.Win32.Networking.WinInet.INTERNET_AUTODIAL = 1
INTERNET_AUTODIAL_FORCE_UNATTENDED: win32more.Windows.Win32.Networking.WinInet.INTERNET_AUTODIAL = 2
INTERNET_AUTODIAL_OVERRIDE_NET_PRESENT: win32more.Windows.Win32.Networking.WinInet.INTERNET_AUTODIAL = 8
class INTERNET_BUFFERSA(Structure):
    dwStructSize: UInt32
    Next: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSA)
    lpcszHeader: win32more.Windows.Win32.Foundation.PSTR
    dwHeadersLength: UInt32
    dwHeadersTotal: UInt32
    lpvBuffer: VoidPtr
    dwBufferLength: UInt32
    dwBufferTotal: UInt32
    dwOffsetLow: UInt32
    dwOffsetHigh: UInt32
class INTERNET_BUFFERSW(Structure):
    dwStructSize: UInt32
    Next: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_BUFFERSW)
    lpcszHeader: win32more.Windows.Win32.Foundation.PWSTR
    dwHeadersLength: UInt32
    dwHeadersTotal: UInt32
    lpvBuffer: VoidPtr
    dwBufferLength: UInt32
    dwBufferTotal: UInt32
    dwOffsetLow: UInt32
    dwOffsetHigh: UInt32
INTERNET_BUFFERS = UnicodeAlias('INTERNET_BUFFERSW')
class INTERNET_CACHE_CONFIG_INFOA(Structure):
    dwStructSize: UInt32
    dwContainer: UInt32
    dwQuota: UInt32
    dwReserved4: UInt32
    fPerUser: win32more.Windows.Win32.Foundation.BOOL
    dwSyncMode: UInt32
    dwNumCachePaths: UInt32
    Anonymous: _Anonymous_e__Union
    dwNormalUsage: UInt32
    dwExemptUsage: UInt32
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        CachePaths: win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONFIG_PATH_ENTRYA * 1
        class _Anonymous_e__Struct(Structure):
            CachePath: win32more.Windows.Win32.Foundation.CHAR * 260
            dwCacheSize: UInt32
class INTERNET_CACHE_CONFIG_INFOW(Structure):
    dwStructSize: UInt32
    dwContainer: UInt32
    dwQuota: UInt32
    dwReserved4: UInt32
    fPerUser: win32more.Windows.Win32.Foundation.BOOL
    dwSyncMode: UInt32
    dwNumCachePaths: UInt32
    Anonymous: _Anonymous_e__Union
    dwNormalUsage: UInt32
    dwExemptUsage: UInt32
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        CachePaths: win32more.Windows.Win32.Networking.WinInet.INTERNET_CACHE_CONFIG_PATH_ENTRYW * 1
        class _Anonymous_e__Struct(Structure):
            CachePath: Char * 260
            dwCacheSize: UInt32
INTERNET_CACHE_CONFIG_INFO = UnicodeAlias('INTERNET_CACHE_CONFIG_INFOW')
class INTERNET_CACHE_CONFIG_PATH_ENTRYA(Structure):
    CachePath: win32more.Windows.Win32.Foundation.CHAR * 260
    dwCacheSize: UInt32
class INTERNET_CACHE_CONFIG_PATH_ENTRYW(Structure):
    CachePath: Char * 260
    dwCacheSize: UInt32
INTERNET_CACHE_CONFIG_PATH_ENTRY = UnicodeAlias('INTERNET_CACHE_CONFIG_PATH_ENTRYW')
class INTERNET_CACHE_CONTAINER_INFOA(Structure):
    dwCacheVersion: UInt32
    lpszName: win32more.Windows.Win32.Foundation.PSTR
    lpszCachePrefix: win32more.Windows.Win32.Foundation.PSTR
    lpszVolumeLabel: win32more.Windows.Win32.Foundation.PSTR
    lpszVolumeTitle: win32more.Windows.Win32.Foundation.PSTR
class INTERNET_CACHE_CONTAINER_INFOW(Structure):
    dwCacheVersion: UInt32
    lpszName: win32more.Windows.Win32.Foundation.PWSTR
    lpszCachePrefix: win32more.Windows.Win32.Foundation.PWSTR
    lpszVolumeLabel: win32more.Windows.Win32.Foundation.PWSTR
    lpszVolumeTitle: win32more.Windows.Win32.Foundation.PWSTR
INTERNET_CACHE_CONTAINER_INFO = UnicodeAlias('INTERNET_CACHE_CONTAINER_INFOW')
class INTERNET_CACHE_ENTRY_INFOA(Structure):
    dwStructSize: UInt32
    lpszSourceUrlName: win32more.Windows.Win32.Foundation.PSTR
    lpszLocalFileName: win32more.Windows.Win32.Foundation.PSTR
    CacheEntryType: UInt32
    dwUseCount: UInt32
    dwHitRate: UInt32
    dwSizeLow: UInt32
    dwSizeHigh: UInt32
    LastModifiedTime: win32more.Windows.Win32.Foundation.FILETIME
    ExpireTime: win32more.Windows.Win32.Foundation.FILETIME
    LastAccessTime: win32more.Windows.Win32.Foundation.FILETIME
    LastSyncTime: win32more.Windows.Win32.Foundation.FILETIME
    lpHeaderInfo: win32more.Windows.Win32.Foundation.PSTR
    dwHeaderInfoSize: UInt32
    lpszFileExtension: win32more.Windows.Win32.Foundation.PSTR
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        dwReserved: UInt32
        dwExemptDelta: UInt32
class INTERNET_CACHE_ENTRY_INFOW(Structure):
    dwStructSize: UInt32
    lpszSourceUrlName: win32more.Windows.Win32.Foundation.PWSTR
    lpszLocalFileName: win32more.Windows.Win32.Foundation.PWSTR
    CacheEntryType: UInt32
    dwUseCount: UInt32
    dwHitRate: UInt32
    dwSizeLow: UInt32
    dwSizeHigh: UInt32
    LastModifiedTime: win32more.Windows.Win32.Foundation.FILETIME
    ExpireTime: win32more.Windows.Win32.Foundation.FILETIME
    LastAccessTime: win32more.Windows.Win32.Foundation.FILETIME
    LastSyncTime: win32more.Windows.Win32.Foundation.FILETIME
    lpHeaderInfo: win32more.Windows.Win32.Foundation.PWSTR
    dwHeaderInfoSize: UInt32
    lpszFileExtension: win32more.Windows.Win32.Foundation.PWSTR
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        dwReserved: UInt32
        dwExemptDelta: UInt32
INTERNET_CACHE_ENTRY_INFO = UnicodeAlias('INTERNET_CACHE_ENTRY_INFOW')
class INTERNET_CACHE_GROUP_INFOA(Structure):
    dwGroupSize: UInt32
    dwGroupFlags: UInt32
    dwGroupType: UInt32
    dwDiskUsage: UInt32
    dwDiskQuota: UInt32
    dwOwnerStorage: UInt32 * 4
    szGroupName: win32more.Windows.Win32.Foundation.CHAR * 120
class INTERNET_CACHE_GROUP_INFOW(Structure):
    dwGroupSize: UInt32
    dwGroupFlags: UInt32
    dwGroupType: UInt32
    dwDiskUsage: UInt32
    dwDiskQuota: UInt32
    dwOwnerStorage: UInt32 * 4
    szGroupName: Char * 120
INTERNET_CACHE_GROUP_INFO = UnicodeAlias('INTERNET_CACHE_GROUP_INFOW')
class INTERNET_CACHE_TIMESTAMPS(Structure):
    ftExpires: win32more.Windows.Win32.Foundation.FILETIME
    ftLastModified: win32more.Windows.Win32.Foundation.FILETIME
class INTERNET_CALLBACK_COOKIE(Structure):
    pcwszName: win32more.Windows.Win32.Foundation.PWSTR
    pcwszValue: win32more.Windows.Win32.Foundation.PWSTR
    pcwszDomain: win32more.Windows.Win32.Foundation.PWSTR
    pcwszPath: win32more.Windows.Win32.Foundation.PWSTR
    ftExpires: win32more.Windows.Win32.Foundation.FILETIME
    dwFlags: UInt32
class INTERNET_CERTIFICATE_INFO(Structure):
    ftExpiry: win32more.Windows.Win32.Foundation.FILETIME
    ftStart: win32more.Windows.Win32.Foundation.FILETIME
    lpszSubjectInfo: POINTER(SByte)
    lpszIssuerInfo: POINTER(SByte)
    lpszProtocolName: POINTER(SByte)
    lpszSignatureAlgName: POINTER(SByte)
    lpszEncryptionAlgName: POINTER(SByte)
    dwKeySize: UInt32
class INTERNET_CONNECTED_INFO(Structure):
    dwConnectedState: win32more.Windows.Win32.Networking.WinInet.INTERNET_STATE
    dwFlags: UInt32
INTERNET_CONNECTION = UInt32
INTERNET_CONNECTION_CONFIGURED: win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION = 64
INTERNET_CONNECTION_LAN: win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION = 2
INTERNET_CONNECTION_MODEM: win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION = 1
INTERNET_CONNECTION_MODEM_BUSY: win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION = 8
INTERNET_CONNECTION_OFFLINE: win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION = 32
INTERNET_CONNECTION_PROXY: win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION = 4
INTERNET_RAS_INSTALLED: win32more.Windows.Win32.Networking.WinInet.INTERNET_CONNECTION = 16
class INTERNET_COOKIE(Structure):
    cbSize: UInt32
    pszName: win32more.Windows.Win32.Foundation.PSTR
    pszData: win32more.Windows.Win32.Foundation.PSTR
    pszDomain: win32more.Windows.Win32.Foundation.PSTR
    pszPath: win32more.Windows.Win32.Foundation.PSTR
    pftExpires: POINTER(win32more.Windows.Win32.Foundation.FILETIME)
    dwFlags: UInt32
    pszUrl: win32more.Windows.Win32.Foundation.PSTR
    pszP3PPolicy: win32more.Windows.Win32.Foundation.PSTR
class INTERNET_COOKIE2(Structure):
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    pwszValue: win32more.Windows.Win32.Foundation.PWSTR
    pwszDomain: win32more.Windows.Win32.Foundation.PWSTR
    pwszPath: win32more.Windows.Win32.Foundation.PWSTR
    dwFlags: UInt32
    ftExpires: win32more.Windows.Win32.Foundation.FILETIME
    fExpiresSet: win32more.Windows.Win32.Foundation.BOOL
INTERNET_COOKIE_FLAGS = UInt32
INTERNET_COOKIE_HTTPONLY: win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE_FLAGS = 8192
INTERNET_COOKIE_THIRD_PARTY: win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE_FLAGS = 16
INTERNET_FLAG_RESTRICTED_ZONE: win32more.Windows.Win32.Networking.WinInet.INTERNET_COOKIE_FLAGS = 131072
class INTERNET_CREDENTIALS(Structure):
    lpcwszHostName: win32more.Windows.Win32.Foundation.PWSTR
    dwPort: UInt32
    dwScheme: UInt32
    lpcwszUrl: win32more.Windows.Win32.Foundation.PWSTR
    lpcwszRealm: win32more.Windows.Win32.Foundation.PWSTR
    fAuthIdentity: win32more.Windows.Win32.Foundation.BOOL
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        pAuthIdentityOpaque: VoidPtr
        class _Anonymous_e__Struct(Structure):
            lpcwszUserName: win32more.Windows.Win32.Foundation.PWSTR
            lpcwszPassword: win32more.Windows.Win32.Foundation.PWSTR
class INTERNET_DIAGNOSTIC_SOCKET_INFO(Structure):
    Socket: UIntPtr
    SourcePort: UInt32
    DestPort: UInt32
    Flags: UInt32
class INTERNET_DOWNLOAD_MODE_HANDLE(Structure):
    pcwszFileName: win32more.Windows.Win32.Foundation.PWSTR
    phFile: POINTER(win32more.Windows.Win32.Foundation.HANDLE)
class INTERNET_END_BROWSER_SESSION_DATA(Structure):
    lpBuffer: VoidPtr
    dwBufferLength: UInt32
INTERNET_PER_CONN = UInt32
INTERNET_PER_CONN_AUTOCONFIG_URL: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 4
INTERNET_PER_CONN_AUTODISCOVERY_FLAGS: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 5
INTERNET_PER_CONN_FLAGS: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 1
INTERNET_PER_CONN_PROXY_BYPASS: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 3
INTERNET_PER_CONN_PROXY_SERVER: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 2
INTERNET_PER_CONN_AUTOCONFIG_SECONDARY_URL: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 6
INTERNET_PER_CONN_AUTOCONFIG_RELOAD_DELAY_MINS: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 7
INTERNET_PER_CONN_AUTOCONFIG_LAST_DETECT_TIME: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 8
INTERNET_PER_CONN_AUTOCONFIG_LAST_DETECT_URL: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN = 9
class INTERNET_PER_CONN_OPTIONA(Structure):
    dwOption: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN
    Value: _Value_e__Union
    class _Value_e__Union(Union):
        dwValue: UInt32
        pszValue: win32more.Windows.Win32.Foundation.PSTR
        ftValue: win32more.Windows.Win32.Foundation.FILETIME
class INTERNET_PER_CONN_OPTIONW(Structure):
    dwOption: win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN
    Value: _Value_e__Union
    class _Value_e__Union(Union):
        dwValue: UInt32
        pszValue: win32more.Windows.Win32.Foundation.PWSTR
        ftValue: win32more.Windows.Win32.Foundation.FILETIME
INTERNET_PER_CONN_OPTION = UnicodeAlias('INTERNET_PER_CONN_OPTIONW')
class INTERNET_PER_CONN_OPTION_LISTA(Structure):
    dwSize: UInt32
    pszConnection: win32more.Windows.Win32.Foundation.PSTR
    dwOptionCount: UInt32
    dwOptionError: UInt32
    pOptions: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN_OPTIONA)
class INTERNET_PER_CONN_OPTION_LISTW(Structure):
    dwSize: UInt32
    pszConnection: win32more.Windows.Win32.Foundation.PWSTR
    dwOptionCount: UInt32
    dwOptionError: UInt32
    pOptions: POINTER(win32more.Windows.Win32.Networking.WinInet.INTERNET_PER_CONN_OPTIONW)
INTERNET_PER_CONN_OPTION_LIST = UnicodeAlias('INTERNET_PER_CONN_OPTION_LISTW')
class INTERNET_PREFETCH_STATUS(Structure):
    dwStatus: UInt32
    dwSize: UInt32
class INTERNET_PROXY_INFO(Structure):
    dwAccessType: win32more.Windows.Win32.Networking.WinInet.INTERNET_ACCESS_TYPE
    lpszProxy: POINTER(SByte)
    lpszProxyBypass: POINTER(SByte)
INTERNET_SCHEME = Int32
INTERNET_SCHEME_PARTIAL: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = -2
INTERNET_SCHEME_UNKNOWN: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = -1
INTERNET_SCHEME_DEFAULT: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 0
INTERNET_SCHEME_FTP: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 1
INTERNET_SCHEME_GOPHER: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 2
INTERNET_SCHEME_HTTP: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 3
INTERNET_SCHEME_HTTPS: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 4
INTERNET_SCHEME_FILE: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 5
INTERNET_SCHEME_NEWS: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 6
INTERNET_SCHEME_MAILTO: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 7
INTERNET_SCHEME_SOCKS: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 8
INTERNET_SCHEME_JAVASCRIPT: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 9
INTERNET_SCHEME_VBSCRIPT: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 10
INTERNET_SCHEME_RES: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 11
INTERNET_SCHEME_FIRST: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 1
INTERNET_SCHEME_LAST: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME = 11
class INTERNET_SECURITY_CONNECTION_INFO(Structure):
    dwSize: UInt32
    fSecure: win32more.Windows.Win32.Foundation.BOOL
    connectionInfo: win32more.Windows.Win32.Security.Authentication.Identity.SecPkgContext_ConnectionInfo
    cipherInfo: win32more.Windows.Win32.Security.Authentication.Identity.SecPkgContext_CipherInfo
class INTERNET_SECURITY_INFO(Structure):
    dwSize: UInt32
    pCertificate: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT)
    pcCertChain: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CHAIN_CONTEXT)
    connectionInfo: win32more.Windows.Win32.Security.Authentication.Identity.SecPkgContext_ConnectionInfo
    cipherInfo: win32more.Windows.Win32.Security.Authentication.Identity.SecPkgContext_CipherInfo
    pcUnverifiedCertChain: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CHAIN_CONTEXT)
    channelBindingToken: win32more.Windows.Win32.Security.Authentication.Identity.SecPkgContext_Bindings
class INTERNET_SERVER_CONNECTION_STATE(Structure):
    lpcwszHostName: win32more.Windows.Win32.Foundation.PWSTR
    fProxy: win32more.Windows.Win32.Foundation.BOOL
    dwCounter: UInt32
    dwConnectionLimit: UInt32
    dwAvailableCreates: UInt32
    dwAvailableKeepAlives: UInt32
    dwActiveConnections: UInt32
    dwWaiters: UInt32
INTERNET_STATE = UInt32
INTERNET_STATE_CONNECTED: win32more.Windows.Win32.Networking.WinInet.INTERNET_STATE = 1
INTERNET_STATE_DISCONNECTED: win32more.Windows.Win32.Networking.WinInet.INTERNET_STATE = 2
INTERNET_STATE_DISCONNECTED_BY_USER: win32more.Windows.Win32.Networking.WinInet.INTERNET_STATE = 16
INTERNET_STATE_IDLE: win32more.Windows.Win32.Networking.WinInet.INTERNET_STATE = 256
INTERNET_STATE_BUSY: win32more.Windows.Win32.Networking.WinInet.INTERNET_STATE = 512
class INTERNET_VERSION_INFO(Structure):
    dwMajorVersion: UInt32
    dwMinorVersion: UInt32
class IProofOfPossessionCookieInfoManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cdaece56-4edf-43df-b113-88e4556fa1bb}')
    @commethod(3)
    def GetCookieInfoForUri(self, uri: win32more.Windows.Win32.Foundation.PWSTR, cookieInfoCount: POINTER(UInt32), cookieInfo: POINTER(POINTER(win32more.Windows.Win32.Networking.WinInet.ProofOfPossessionCookieInfo))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IProofOfPossessionCookieInfoManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{15e41407-b42f-4ae7-9966-34a087b2d713}')
    @commethod(3)
    def GetCookieInfoWithUriForAccount(self, webAccount: win32more.Windows.Win32.System.WinRT.IInspectable, uri: win32more.Windows.Win32.Foundation.PWSTR, cookieInfoCount: POINTER(UInt32), cookieInfo: POINTER(POINTER(win32more.Windows.Win32.Networking.WinInet.ProofOfPossessionCookieInfo))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IncomingCookieState(Structure):
    cSession: Int32
    cPersistent: Int32
    cAccepted: Int32
    cLeashed: Int32
    cDowngraded: Int32
    cBlocked: Int32
    pszLocation: win32more.Windows.Win32.Foundation.PSTR
class InternetCookieHistory(Structure):
    fAccepted: win32more.Windows.Win32.Foundation.BOOL
    fLeashed: win32more.Windows.Win32.Foundation.BOOL
    fDowngraded: win32more.Windows.Win32.Foundation.BOOL
    fRejected: win32more.Windows.Win32.Foundation.BOOL
InternetCookieState = Int32
COOKIE_STATE_UNKNOWN: win32more.Windows.Win32.Networking.WinInet.InternetCookieState = 0
COOKIE_STATE_ACCEPT: win32more.Windows.Win32.Networking.WinInet.InternetCookieState = 1
COOKIE_STATE_PROMPT: win32more.Windows.Win32.Networking.WinInet.InternetCookieState = 2
COOKIE_STATE_LEASH: win32more.Windows.Win32.Networking.WinInet.InternetCookieState = 3
COOKIE_STATE_DOWNGRADE: win32more.Windows.Win32.Networking.WinInet.InternetCookieState = 4
COOKIE_STATE_REJECT: win32more.Windows.Win32.Networking.WinInet.InternetCookieState = 5
COOKIE_STATE_MAX: win32more.Windows.Win32.Networking.WinInet.InternetCookieState = 5
@winfunctype_pointer
def LPINTERNET_STATUS_CALLBACK(hInternet: VoidPtr, dwContext: UIntPtr, dwInternetStatus: UInt32, lpvStatusInformation: VoidPtr, dwStatusInformationLength: UInt32) -> Void: ...
class OutgoingCookieState(Structure):
    cSent: Int32
    cSuppressed: Int32
    pszLocation: win32more.Windows.Win32.Foundation.PSTR
@winfunctype_pointer
def PFN_AUTH_NOTIFY(param0: UIntPtr, param1: UInt32, param2: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def PFN_DIAL_HANDLER(param0: win32more.Windows.Win32.Foundation.HWND, param1: win32more.Windows.Win32.Foundation.PSTR, param2: UInt32, param3: POINTER(UInt32)) -> UInt32: ...
PROXY_AUTO_DETECT_TYPE = UInt32
PROXY_AUTO_DETECT_TYPE_DHCP: win32more.Windows.Win32.Networking.WinInet.PROXY_AUTO_DETECT_TYPE = 1
PROXY_AUTO_DETECT_TYPE_DNS_A: win32more.Windows.Win32.Networking.WinInet.PROXY_AUTO_DETECT_TYPE = 2
class ProofOfPossessionCookieInfo(Structure):
    name: win32more.Windows.Win32.Foundation.PWSTR
    data: win32more.Windows.Win32.Foundation.PWSTR
    flags: UInt32
    p3pHeader: win32more.Windows.Win32.Foundation.PWSTR
ProofOfPossessionCookieInfoManager = Guid('{a9927f85-a304-4390-8b23-a75f1c668600}')
REQUEST_TIMES = Int32
NameResolutionStart: win32more.Windows.Win32.Networking.WinInet.REQUEST_TIMES = 0
NameResolutionEnd: win32more.Windows.Win32.Networking.WinInet.REQUEST_TIMES = 1
ConnectionEstablishmentStart: win32more.Windows.Win32.Networking.WinInet.REQUEST_TIMES = 2
ConnectionEstablishmentEnd: win32more.Windows.Win32.Networking.WinInet.REQUEST_TIMES = 3
TLSHandshakeStart: win32more.Windows.Win32.Networking.WinInet.REQUEST_TIMES = 4
TLSHandshakeEnd: win32more.Windows.Win32.Networking.WinInet.REQUEST_TIMES = 5
HttpRequestTimeMax: win32more.Windows.Win32.Networking.WinInet.REQUEST_TIMES = 32
class URLCACHE_ENTRY_INFO(Structure):
    pwszSourceUrlName: win32more.Windows.Win32.Foundation.PWSTR
    pwszLocalFileName: win32more.Windows.Win32.Foundation.PWSTR
    dwCacheEntryType: UInt32
    dwUseCount: UInt32
    dwHitRate: UInt32
    dwSizeLow: UInt32
    dwSizeHigh: UInt32
    ftLastModifiedTime: win32more.Windows.Win32.Foundation.FILETIME
    ftExpireTime: win32more.Windows.Win32.Foundation.FILETIME
    ftLastAccessTime: win32more.Windows.Win32.Foundation.FILETIME
    ftLastSyncTime: win32more.Windows.Win32.Foundation.FILETIME
    pbHeaderInfo: POINTER(Byte)
    cbHeaderInfoSize: UInt32
    pbExtraData: POINTER(Byte)
    cbExtraDataSize: UInt32
URL_CACHE_LIMIT_TYPE = Int32
UrlCacheLimitTypeIE: win32more.Windows.Win32.Networking.WinInet.URL_CACHE_LIMIT_TYPE = 0
UrlCacheLimitTypeIETotal: win32more.Windows.Win32.Networking.WinInet.URL_CACHE_LIMIT_TYPE = 1
UrlCacheLimitTypeAppContainer: win32more.Windows.Win32.Networking.WinInet.URL_CACHE_LIMIT_TYPE = 2
UrlCacheLimitTypeAppContainerTotal: win32more.Windows.Win32.Networking.WinInet.URL_CACHE_LIMIT_TYPE = 3
UrlCacheLimitTypeNum: win32more.Windows.Win32.Networking.WinInet.URL_CACHE_LIMIT_TYPE = 4
class URL_COMPONENTSA(Structure):
    dwStructSize: UInt32
    lpszScheme: win32more.Windows.Win32.Foundation.PSTR
    dwSchemeLength: UInt32
    nScheme: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME
    lpszHostName: win32more.Windows.Win32.Foundation.PSTR
    dwHostNameLength: UInt32
    nPort: UInt16
    lpszUserName: win32more.Windows.Win32.Foundation.PSTR
    dwUserNameLength: UInt32
    lpszPassword: win32more.Windows.Win32.Foundation.PSTR
    dwPasswordLength: UInt32
    lpszUrlPath: win32more.Windows.Win32.Foundation.PSTR
    dwUrlPathLength: UInt32
    lpszExtraInfo: win32more.Windows.Win32.Foundation.PSTR
    dwExtraInfoLength: UInt32
class URL_COMPONENTSW(Structure):
    dwStructSize: UInt32
    lpszScheme: win32more.Windows.Win32.Foundation.PWSTR
    dwSchemeLength: UInt32
    nScheme: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME
    lpszHostName: win32more.Windows.Win32.Foundation.PWSTR
    dwHostNameLength: UInt32
    nPort: UInt16
    lpszUserName: win32more.Windows.Win32.Foundation.PWSTR
    dwUserNameLength: UInt32
    lpszPassword: win32more.Windows.Win32.Foundation.PWSTR
    dwPasswordLength: UInt32
    lpszUrlPath: win32more.Windows.Win32.Foundation.PWSTR
    dwUrlPathLength: UInt32
    lpszExtraInfo: win32more.Windows.Win32.Foundation.PWSTR
    dwExtraInfoLength: UInt32
URL_COMPONENTS = UnicodeAlias('URL_COMPONENTSW')
class WININET_PROXY_INFO(Structure):
    fProxy: win32more.Windows.Win32.Foundation.BOOL
    fBypass: win32more.Windows.Win32.Foundation.BOOL
    ProxyScheme: win32more.Windows.Win32.Networking.WinInet.INTERNET_SCHEME
    pwszProxy: win32more.Windows.Win32.Foundation.PWSTR
    ProxyPort: UInt16
class WININET_PROXY_INFO_LIST(Structure):
    dwProxyInfoCount: UInt32
    pProxyInfo: POINTER(win32more.Windows.Win32.Networking.WinInet.WININET_PROXY_INFO)
WININET_SYNC_MODE = Int32
WININET_SYNC_MODE_NEVER: win32more.Windows.Win32.Networking.WinInet.WININET_SYNC_MODE = 0
WININET_SYNC_MODE_ON_EXPIRY: win32more.Windows.Win32.Networking.WinInet.WININET_SYNC_MODE = 1
WININET_SYNC_MODE_ONCE_PER_SESSION: win32more.Windows.Win32.Networking.WinInet.WININET_SYNC_MODE = 2
WININET_SYNC_MODE_ALWAYS: win32more.Windows.Win32.Networking.WinInet.WININET_SYNC_MODE = 3
WININET_SYNC_MODE_AUTOMATIC: win32more.Windows.Win32.Networking.WinInet.WININET_SYNC_MODE = 4
WININET_SYNC_MODE_DEFAULT: win32more.Windows.Win32.Networking.WinInet.WININET_SYNC_MODE = 4
WPAD_CACHE_DELETE = Int32
WPAD_CACHE_DELETE_CURRENT: win32more.Windows.Win32.Networking.WinInet.WPAD_CACHE_DELETE = 0
WPAD_CACHE_DELETE_ALL: win32more.Windows.Win32.Networking.WinInet.WPAD_CACHE_DELETE = 1
@winfunctype_pointer
def pfnInternetDeInitializeAutoProxyDll(lpszMime: win32more.Windows.Win32.Foundation.PSTR, dwReserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pfnInternetGetProxyInfo(lpszUrl: win32more.Windows.Win32.Foundation.PSTR, dwUrlLength: UInt32, lpszUrlHostName: win32more.Windows.Win32.Foundation.PSTR, dwUrlHostNameLength: UInt32, lplpszProxyHostName: POINTER(win32more.Windows.Win32.Foundation.PSTR), lpdwProxyHostNameLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pfnInternetInitializeAutoProxyDll(dwVersion: UInt32, lpszDownloadedTempFile: win32more.Windows.Win32.Foundation.PSTR, lpszMime: win32more.Windows.Win32.Foundation.PSTR, lpAutoProxyCallbacks: POINTER(win32more.Windows.Win32.Networking.WinInet.AutoProxyHelperFunctions), lpAutoProxyScriptBuffer: POINTER(win32more.Windows.Win32.Networking.WinInet.AUTO_PROXY_SCRIPT_BUFFER)) -> win32more.Windows.Win32.Foundation.BOOL: ...


make_ready(__name__)
